@@ -1,6 +1,6 @@
 /* FSNBrowserColumn.m
  *  
- * Copyright (C) 2004-2010 Free Software Foundation, Inc.
+ * Copyright (C) 2004-2013 Free Software Foundation, Inc.
  *
  * Author: Enrico Sersale <enrico@imago.ro>
  * Date: July 2004
@@ -159,7 +159,7 @@ static id <DesktopApplication> desktopApp = nil;
   if (infoType != type) {
     NSArray *cells = [matrix cells];
     int lineh = floor([fsnodeRep heighOfFont: [cellPrototype font]]);
-    int i;
+    NSUInteger i;
     
     infoType = type;
     DESTROY (extInfoType);
@@ -187,7 +187,7 @@ static id <DesktopApplication> desktopApp = nil;
   if ((extInfoType == nil) || ([extInfoType isEqual: type] == NO)) {
     NSArray *cells = [matrix cells];    
     int lineh = floor([fsnodeRep heighOfFont: [cellPrototype font]]);  
-    int i;
+    NSUInteger i;
     
     infoType = FSNInfoExtendedType;
     ASSIGN (extInfoType, type);
@@ -202,7 +202,7 @@ static id <DesktopApplication> desktopApp = nil;
 
     [self adjustMatrix];
 
-	  for (i = 0; i < [cells count]; i++) {
+    for (i = 0; i < [cells count]; i++) {
       FSNBrowserCell *cell = [cells objectAtIndex: i];
       [cell setExtendedShowType: extInfoType];
     }       
@@ -214,7 +214,6 @@ static id <DesktopApplication> desktopApp = nil;
   NSArray *savedSelection = nil;
   NSMutableArray *visibleNodes = nil;
   float scrollTune = 0;
-  int i = 0;
 
   if (oldNode && anode && [oldNode isEqualToNode: anode] && [anode isValid]) {
     NSArray *vnodes = nil;  
@@ -255,7 +254,8 @@ static id <DesktopApplication> desktopApp = nil;
     } 
 
     if (visibleNodes) {
-      int count = [visibleNodes count];
+      NSUInteger i;
+      NSUInteger count = [visibleNodes count];
       
       for (i = 0; i < count; i++) {
         FSNode *node = [visibleNodes objectAtIndex: i];
@@ -293,11 +293,11 @@ static id <DesktopApplication> desktopApp = nil;
 
 - (void)createRowsInMatrix
 {
-  CREATE_AUTORELEASE_POOL (pool);
+  NSAutoreleasePool *pool;
   NSArray *subNodes = [shownNode subNodes];
-  int count = [subNodes count];
+  NSUInteger count = [subNodes count];
   SEL compSel = [fsnodeRep compareSelectorForDirectory: [shownNode path]];
-  int i;
+  NSUInteger i;
 
   if ([matrix numberOfColumns] > 0)
     [matrix removeColumn: 0];
@@ -309,6 +309,8 @@ static id <DesktopApplication> desktopApp = nil;
       return;
     }
   
+  pool = [[NSAutoreleasePool alloc] init];
+
   [matrix addColumn]; 
 
   for (i = 0; i < count; ++i)
@@ -354,7 +356,7 @@ static id <DesktopApplication> desktopApp = nil;
     CREATE_AUTORELEASE_POOL(arp);
     NSArray *selectedNodes = [self selectedNodes];
     SEL compSel = [fsnodeRep compareSelectorForDirectory: [shownNode path]];
-    int i;
+    NSUInteger i;
 
     [matrix setIntercellSpacing: NSMakeSize(0, 0)];
     	  
@@ -418,7 +420,7 @@ static id <DesktopApplication> desktopApp = nil;
   id cell = nil;
   float scrollTune = 0;
   BOOL updated = NO;
-  int i;
+  NSUInteger i;
   
   selcells = [matrix selectedCells];
   
@@ -439,7 +441,7 @@ static id <DesktopApplication> desktopApp = nil;
 
     if (cell) {
       FSNode *node = [cell node];
-			int row, col;
+			NSInteger row, col;
       
 			if (visibleNodes && [visibleNodes containsObject: node]) {
 				[visibleNodes removeObject: node];
@@ -496,10 +498,10 @@ static id <DesktopApplication> desktopApp = nil;
 {
   NSArray *selected = [matrix selectedCells];
 
-	if (selected) {
+  if (selected) {
     NSMutableArray *cells = [NSMutableArray array];
     BOOL missing = NO;
-    int i;
+    NSUInteger i;
   
     for (i = 0; i < [selected count]; i++) {  
       FSNBrowserCell *cell = [selected objectAtIndex: i];
@@ -530,10 +532,10 @@ static id <DesktopApplication> desktopApp = nil;
 {
   NSArray *selected = [matrix selectedCells];
 
-	if (selected) {
+  if (selected) {
     NSMutableArray *nodes = [NSMutableArray array];
     BOOL missing = NO;
-    int i;
+    NSUInteger i;
   
     for (i = 0; i < [selected count]; i++) {  
       FSNode *node = [[selected objectAtIndex: i] node];
@@ -564,10 +566,10 @@ static id <DesktopApplication> desktopApp = nil;
 {
   NSArray *selected = [matrix selectedCells];
 
-	if (selected) {
+  if (selected) {
     NSMutableArray *paths = [NSMutableArray array];
     BOOL missing = NO;
-    int i;
+    NSUInteger i;
   
     for (i = 0; i < [selected count]; i++) {  
       FSNode *node = [[selected objectAtIndex: i] node];
@@ -656,7 +658,7 @@ static id <DesktopApplication> desktopApp = nil;
          sendAction:(BOOL)act
 {
   if (cells && [cells count]) {
-    int i;
+    NSUInteger i;
 
     [matrix deselectAllCells];
 
@@ -675,7 +677,7 @@ static id <DesktopApplication> desktopApp = nil;
 {
   if (nodes && [nodes count]) {
     NSArray *cells = [matrix cells];
-    int i;
+    NSUInteger i;
 
     [matrix deselectAllCells];
 
@@ -698,7 +700,7 @@ static id <DesktopApplication> desktopApp = nil;
 {
   if (paths && [paths count]) {
     NSArray *cells = [matrix cells];
-    int i;
+    NSUInteger i;
 
     [matrix deselectAllCells];
 
@@ -721,7 +723,7 @@ static id <DesktopApplication> desktopApp = nil;
 {
   if (names && [names count]) {
     NSArray *cells = [matrix cells];
-    int i;
+    NSUInteger i;
 
     [matrix deselectAllCells];
 
@@ -756,7 +758,7 @@ static id <DesktopApplication> desktopApp = nil;
     int n = [matrix numberOfRows];
     int s = [matrix selectedRow];
     NSString *cellstr = nil;
-    int i = 0;
+    NSUInteger i = 0;
     
     if (s != -1) {
       cellstr = [[matrix cellAtRow: s column: 0] stringValue];
@@ -798,11 +800,11 @@ static id <DesktopApplication> desktopApp = nil;
 {
   if ([[matrix cells] count]) {
     NSArray *cells = [matrix cells];
-    unsigned count = [cells count];
+    NSUInteger count = [cells count];
     FSNBrowserCell *cell;
-    int selstart = 0;
-    int selend = 0;
-    int i;
+    NSUInteger selstart = 0;
+    NSUInteger selend = 0;
+    NSUInteger i;
         
     [matrix deselectAllCells];
 
@@ -883,7 +885,7 @@ static id <DesktopApplication> desktopApp = nil;
 - (void)checkLockedReps
 {
   NSArray *cells = [matrix cells];
-  int i;  
+  NSUInteger i;  
 
   for (i = 0; i < [cells count]; i++) {
     [[cells objectAtIndex: i] checkLocked];
@@ -894,7 +896,7 @@ static id <DesktopApplication> desktopApp = nil;
 
 - (void)lockCellsOfNodes:(NSArray *)nodes
 {
-  int i;
+  NSUInteger i;
   BOOL found = NO;
   
   for (i = 0; i < [nodes count]; i++) {
@@ -911,7 +913,7 @@ static id <DesktopApplication> desktopApp = nil;
 
 - (void)lockCellsWithPaths:(NSArray *)paths
 {
-  int i;
+  NSUInteger i;
   BOOL found = NO;
   
   for (i = 0; i < [paths count]; i++) {
@@ -928,7 +930,7 @@ static id <DesktopApplication> desktopApp = nil;
 
 - (void)lockCellsWithNames:(NSArray *)names
 {
-  int i;
+  NSUInteger i;
   BOOL found = NO;
   
   for (i = 0; i < [names count]; i++) {
@@ -945,7 +947,7 @@ static id <DesktopApplication> desktopApp = nil;
 
 - (void)unLockCellsOfNodes:(NSArray *)nodes
 {
-  int i;
+  NSUInteger i;
   BOOL found = NO;
 
   for (i = 0; i < [nodes count]; i++) {
@@ -962,7 +964,7 @@ static id <DesktopApplication> desktopApp = nil;
 
 - (void)unLockCellsWithPaths:(NSArray *)paths
 {
-  int i;
+  NSUInteger i;
   BOOL found = NO;
 
   for (i = 0; i < [paths count]; i++) {
@@ -979,7 +981,7 @@ static id <DesktopApplication> desktopApp = nil;
 
 - (void)unLockCellsWithNames:(NSArray *)names
 {
-  int i;
+  NSUInteger i;
   BOOL found = NO;
 
   for (i = 0; i < [names count]; i++) {
@@ -997,15 +999,15 @@ static id <DesktopApplication> desktopApp = nil;
 - (void)lock
 {
   NSArray *cells = [matrix cells];
-  int i;  
+  NSUInteger i;  
 
-  for (i = 0; i < [cells count]; i++) {
-		id cell = [cells objectAtIndex: i];
-
-		if ([cell isEnabled]) {
+  for (i = 0; i < [cells count]; i++)
+    {
+      id cell = [cells objectAtIndex: i];
+      
+      if ([cell isEnabled])
     	[cell setEnabled: NO];
-		}
-  }
+    }
 
   [matrix setNeedsDisplay: YES];   
 }
@@ -1013,7 +1015,7 @@ static id <DesktopApplication> desktopApp = nil;
 - (void)unlock
 {
   NSArray *cells = [matrix cells];
-  int i;  
+  NSUInteger i;  
 
   for (i = 0; i < [cells count]; i++) {
 		id cell = [cells objectAtIndex: i];
@@ -1029,15 +1031,15 @@ static id <DesktopApplication> desktopApp = nil;
 - (FSNBrowserCell *)cellOfNode:(FSNode *)node
 {
   NSArray *cells = [matrix cells];
-  int i;
+  NSUInteger i;
 
-	for (i = 0; i < [cells count]; i++) {
-	  FSNBrowserCell *cell = [cells objectAtIndex: i];
-    
-    if ([[cell node] isEqualToNode: node]) {
-      return cell;
-    } 
-	}
+  for (i = 0; i < [cells count]; i++)
+    {
+      FSNBrowserCell *cell = [cells objectAtIndex: i];
+      
+      if ([[cell node] isEqualToNode: node])
+        return cell;
+    }
 
   return nil;
 }            
@@ -1045,7 +1047,7 @@ static id <DesktopApplication> desktopApp = nil;
 - (FSNBrowserCell *)cellWithPath:(NSString *)path
 {
   NSArray *cells = [matrix cells];
-  int i;
+  NSUInteger i;
 
 	for (i = 0; i < [cells count]; i++) {
 	  FSNBrowserCell *cell = [cells objectAtIndex: i];
@@ -1061,7 +1063,7 @@ static id <DesktopApplication> desktopApp = nil;
 - (FSNBrowserCell *)cellWithName:(NSString *)name
 {
   NSArray *cells = [matrix cells];
-  int i;
+  NSUInteger i;
 
   for (i = 0; i < [cells count]; i++)
     {
@@ -1131,7 +1133,7 @@ static id <DesktopApplication> desktopApp = nil;
 - (void)mouseUp:(NSEvent *)theEvent
 {
   NSPoint p = [theEvent locationInWindow];
-  int row, col;
+  NSInteger row, col;
 
   p = [matrix convertPoint: p fromView: nil];
 
@@ -1187,7 +1189,7 @@ static id <DesktopApplication> desktopApp = nil;
   NSString *basePath;
   NSString *nodePath;
   NSString *prePath;
-  int count;
+  NSUInteger count;
   
   isDragTarget = NO;	
   
@@ -1222,10 +1224,9 @@ static id <DesktopApplication> desktopApp = nil;
     return NSDragOperationNone;
   }
 
-	count = [sourcePaths count];
-	if (count == 0) {
-		return NSDragOperationNone;
-  } 
+  count = [sourcePaths count];
+  if (count == 0)
+    return NSDragOperationNone;
     
   if ([shownNode isWritable] == NO) {
     return NSDragOperationNone;
@@ -1256,13 +1257,13 @@ static id <DesktopApplication> desktopApp = nil;
 
   if ([shownNode isDirectory] && [shownNode isParentOfPath: basePath]) {
     NSArray *subNodes = [shownNode subNodes];
-    int i;
+    NSUInteger i;
     
     for (i = 0; i < [subNodes count]; i++) {
       FSNode *nd = [subNodes objectAtIndex: i];
       
       if ([nd isDirectory]) {
-        int j;
+        NSUInteger j;
         
         for (j = 0; j < count; j++) {
           NSString *fname = [[sourcePaths objectAtIndex: j] lastPathComponent];
@@ -1333,18 +1334,18 @@ static id <DesktopApplication> desktopApp = nil;
 
 - (void)concludeDragOperation:(id <NSDraggingInfo>)sender
 {
-	NSPasteboard *pb;
+  NSPasteboard *pb;
   NSDragOperation sourceDragMask;
-	NSArray *sourcePaths;
+  NSArray *sourcePaths;
   NSString *operation, *source;
   NSMutableArray *files;
-	NSMutableDictionary *opDict;
-	NSString *trashPath;
-  int i;
+  NSMutableDictionary *opDict;
+  NSString *trashPath;
+  NSUInteger i;
 
-	isDragTarget = NO;  
+  isDragTarget = NO;  
 
-	sourceDragMask = [sender draggingSourceOperationMask];
+  sourceDragMask = [sender draggingSourceOperationMask];
   pb = [sender draggingPasteboard];
     
   if ([[pb types] containsObject: @"GWRemoteFilenamesPboardType"]) {  
@@ -1364,9 +1365,8 @@ static id <DesktopApplication> desktopApp = nil;
     
   sourcePaths = [pb propertyListForType: NSFilenamesPboardType];
   
-  if ([sourcePaths count] == 0) {
+  if ([sourcePaths count] == 0)
     return;
-  }
   
   source = [[sourcePaths objectAtIndex: 0] stringByDeletingLastPathComponent];
   
@@ -1389,15 +1389,15 @@ static id <DesktopApplication> desktopApp = nil;
   }
 
   files = [NSMutableArray array];    
-  for(i = 0; i < [sourcePaths count]; i++) {    
+  for(i = 0; i < [sourcePaths count]; i++)
+    
     [files addObject: [[sourcePaths objectAtIndex: i] lastPathComponent]];
-  }  
-
-	opDict = [NSMutableDictionary dictionary];
-	[opDict setObject: operation forKey: @"operation"];
-	[opDict setObject: source forKey: @"source"];
-	[opDict setObject: [shownNode path] forKey: @"destination"];
-	[opDict setObject: files forKey: @"files"];
+  
+  opDict = [NSMutableDictionary dictionary];
+  [opDict setObject: operation forKey: @"operation"];
+  [opDict setObject: source forKey: @"source"];
+  [opDict setObject: [shownNode path] forKey: @"destination"];
+  [opDict setObject: files forKey: @"files"];
 
   [desktopApp performFileOperation: opDict];
 }
@@ -1405,14 +1405,14 @@ static id <DesktopApplication> desktopApp = nil;
 - (NSDragOperation)draggingEntered:(id <NSDraggingInfo>)sender
                       inMatrixCell:(id)cell
 {
-	NSPasteboard *pb = [sender draggingPasteboard];
+  NSPasteboard *pb = [sender draggingPasteboard];
   NSDragOperation sourceDragMask = [sender draggingSourceOperationMask];
   FSNode *node = [cell node];
   NSString *nodePath = [node path];
-	NSArray *sourcePaths;
-	NSString *fromPath;
+  NSArray *sourcePaths;
+  NSString *fromPath;
   NSString *prePath;
-	unsigned i, count;
+  NSUInteger i, count;
 
   if (([cell isEnabled] == NO) || ([node isDirectory] == NO) 
             || ([node isPackage] && ([node isApplication] == NO))
@@ -1480,6 +1480,7 @@ static id <DesktopApplication> desktopApp = nil;
       break;
     }            
     prePath = [prePath stringByDeletingLastPathComponent];
+    RELEASE (arp);
   }
 
   if ([node isApplication]) {
@@ -1502,7 +1503,7 @@ static id <DesktopApplication> desktopApp = nil;
       FSNode *nd = [subNodes objectAtIndex: i];
       
       if ([nd isDirectory]) {
-        int j;
+        NSUInteger j;
         
         for (j = 0; j < count; j++) {
           NSString *fname = [[sourcePaths objectAtIndex: j] lastPathComponent];
@@ -1542,7 +1543,7 @@ static id <DesktopApplication> desktopApp = nil;
   NSMutableArray *files;
   NSMutableDictionary *opDict;
   NSString *trashPath;
-  unsigned i;
+  NSUInteger i;
 
   if (([cell isEnabled] == NO) 
                   || ([cell isLeaf] && ([node isApplication] == NO))) {
@@ -1626,5 +1627,3 @@ static id <DesktopApplication> desktopApp = nil;
 
 @end
 
-
-
