@@ -1,6 +1,6 @@
 /* FSNIcon.m
  *  
- * Copyright (C) 2004-2011 Free Software Foundation, Inc.
+ * Copyright (C) 2004-2013 Free Software Foundation, Inc.
  *
  * Author: Enrico Sersale <enrico@imago.ro>
  * Date: March 2004
@@ -98,10 +98,10 @@ static NSImage *branchImage;
      nodeInfoType:(FSNInfoType)type
      extendedType:(NSString *)exttype
          iconSize:(int)isize
-     iconPosition:(unsigned int)ipos
+     iconPosition:(NSUInteger)ipos
         labelFont:(NSFont *)lfont
         textColor:(NSColor *)tcolor
-        gridIndex:(int)gindex
+        gridIndex:(NSUInteger)gindex
         dndSource:(BOOL)dndsrc
         acceptDnd:(BOOL)dndaccept
         slideBack:(BOOL)slback
@@ -1087,12 +1087,12 @@ static NSImage *branchImage;
 	return isLocked;
 }
 
-- (void)setGridIndex:(int)index
+- (void)setGridIndex:(NSUInteger)index
 {
   gridIndex = index;
 }
 
-- (int)gridIndex
+- (NSUInteger)gridIndex
 {
   return gridIndex;
 }
@@ -1167,16 +1167,16 @@ static NSImage *branchImage;
   }
 }
 
-- (unsigned int)draggingSourceOperationMaskForLocal:(BOOL)flag
+- (NSDragOperation)draggingSourceOperationMaskForLocal:(BOOL)flag
 {
   return NSDragOperationEvery;
 }
 
 - (void)draggedImage:(NSImage *)anImage 
-						 endedAt:(NSPoint)aPoint 
-					 deposited:(BOOL)flag
+             endedAt:(NSPoint)aPoint 
+           deposited:(BOOL)flag
 {
-	dragdelay = 0;
+  dragdelay = 0;
   onSelf = NO;
   
   if ([container respondsToSelector: @selector(restoreLastSelection)]) {
@@ -1197,13 +1197,13 @@ static NSImage *branchImage;
 
 - (NSDragOperation)draggingEntered:(id <NSDraggingInfo>)sender
 {
-	NSPasteboard *pb;
+  NSPasteboard *pb;
   NSDragOperation sourceDragMask;
-	NSArray *sourcePaths;
-	NSString *fromPath;
+  NSArray *sourcePaths;
+  NSString *fromPath;
   NSString *nodePath;
   NSString *prePath;
-	unsigned i, count;
+  NSUInteger i, count;
   
   isDragTarget = NO;
   onSelf = NO;
@@ -1229,7 +1229,7 @@ static NSImage *branchImage;
     }
   }
   
-	pb = [sender draggingPasteboard];
+  pb = [sender draggingPasteboard];
   sourcePaths = nil;
   
   if ([[pb types] containsObject: NSFilenamesPboardType]) {
@@ -1255,10 +1255,11 @@ static NSImage *branchImage;
     return NSDragOperationNone;
   }
   
-	count = [sourcePaths count];
-	if (count == 0) {
-		return NSDragOperationNone;
-  } 
+  count = [sourcePaths count];
+  if (count == 0)
+    {
+      return NSDragOperationNone;
+    } 
   
   nodePath = [node path];
   
@@ -1277,11 +1278,12 @@ static NSImage *branchImage;
     return NSDragOperationAll;  
   }
 
-	fromPath = [[sourcePaths objectAtIndex: 0] stringByDeletingLastPathComponent];
+  fromPath = [[sourcePaths objectAtIndex: 0] stringByDeletingLastPathComponent];
 
-	if ([nodePath isEqual: fromPath]) {
-		return NSDragOperationNone;
-  }  
+  if ([nodePath isEqual: fromPath])
+    {
+      return NSDragOperationNone;
+    }  
 
   if ([sourcePaths containsObject: nodePath]) {
     return NSDragOperationNone;
@@ -1289,19 +1291,13 @@ static NSImage *branchImage;
 
   prePath = [NSString stringWithString: nodePath];
 
-  while (1) {
-    CREATE_AUTORELEASE_POOL(arp);
-    
-    if ([sourcePaths containsObject: prePath]) {
-      RELEASE (arp);
-      return NSDragOperationNone;
+  while (![prePath isEqual: path_separator()])
+    {
+      if ([sourcePaths containsObject: prePath])
+        return NSDragOperationNone;
+      prePath = [prePath stringByDeletingLastPathComponent];
     }
-    if ([prePath isEqual: path_separator()]) {
-      RELEASE (arp);
-      break;
-    }            
-    prePath = [prePath stringByDeletingLastPathComponent];
-  }
+
 
   if ([node isDirectory] && [node isParentOfPath: fromPath]) {
     NSArray *subNodes = [node subNodes];
@@ -1449,16 +1445,16 @@ static NSImage *branchImage;
 
 - (void)concludeDragOperation:(id <NSDraggingInfo>)sender
 {
-	NSPasteboard *pb;
+  NSPasteboard *pb;
   NSDragOperation sourceDragMask;
-	NSArray *sourcePaths;
+  NSArray *sourcePaths;
   NSString *operation, *source;
   NSMutableArray *files;
-	NSMutableDictionary *opDict;
-	NSString *trashPath;
-  unsigned i;
+  NSMutableDictionary *opDict;
+  NSString *trashPath;
+  NSUInteger i;
 
-	isDragTarget = NO;  
+  isDragTarget = NO;  
 
   if (isLocked) {
     return;
