@@ -1,6 +1,6 @@
 /* FSNIconsView.h
  *  
- * Copyright (C) 2004 Free Software Foundation, Inc.
+ * Copyright (C) 2004-2013 Free Software Foundation, Inc.
  *
  * Author: Enrico Sersale <enrico@imago.ro>
  * Date: March 2004
@@ -22,12 +22,11 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111 USA.
  */
 
-#ifndef FSN_ICONS_VIEW_H
-#define FSN_ICONS_VIEW_H
 
-#include <Foundation/Foundation.h>
-#include <AppKit/NSView.h>
-#include "FSNodeRep.h"
+#import <Foundation/Foundation.h>
+#import <AppKit/NSView.h>
+#import <AppKit/NSTextField.h>
+#import "FSNodeRep.h"
 
 @class NSColor;
 @class NSFont;
@@ -35,7 +34,7 @@
 @class FSNIcon;
 @class FSNIconNameEditor;
 
-@interface FSNIconsView : NSView
+@interface FSNIconsView : NSView <NSTextFieldDelegate>
 {
   FSNode *node;
   NSMutableArray *icons;
@@ -59,15 +58,16 @@
   NSSize gridSize;
   int colcount;
 
-	BOOL isDragTarget;
+  BOOL isDragTarget;
   BOOL forceCopy;
   
   NSString *charBuffer;	
-	NSTimeInterval lastKeyPressed;
+  NSTimeInterval lastKeyPressed;
   
   NSColor *backColor;
   NSColor *textColor;
   NSColor *disabledTextColor;
+  BOOL transparentSelection;
 
   FSNodeRep *fsnodeRep;
 
@@ -192,5 +192,3 @@
 - (void)controlTextDidEndEditing:(NSNotification *)aNotification;
 
 @end
-
-#endif // FSN_ICONS_VIEW_H
