@@ -1,6 +1,6 @@
 /* FSNListView.m
  *  
- * Copyright (C) 2004-2011 Free Software Foundation, Inc.
+ * Copyright (C) 2004-2013 Free Software Foundation, Inc.
  *
  * Author: Enrico Sersale <enrico@imago.ro>
  * Date: December 2004
@@ -287,7 +287,7 @@ static NSString *defaultColumns = @"{ \
   }
 }
 
-- (void)setMouseFlags:(unsigned int)flags
+- (void)setMouseFlags:(NSUInteger)flags
 {
   mouseFlags = flags;
 }
@@ -396,7 +396,7 @@ static NSString *defaultColumns = @"{ \
 
 - (id)tableView:(NSTableView *)aTableView
           objectValueForTableColumn:(NSTableColumn *)aTableColumn
-                                row:(int)rowIndex
+                                row:(NSInteger)rowIndex
 {
   int ident = [[aTableColumn identifier] intValue];
   FSNListViewNodeRep *rep = [nodeReps objectAtIndex: rowIndex];
@@ -435,7 +435,7 @@ static NSString *defaultColumns = @"{ \
 - (void)tableView:(NSTableView *)aTableView 
             setObjectValue:(id)anObject 
             forTableColumn:(NSTableColumn *)aTableColumn 
-                       row:(int)rowIndex
+                       row:(NSInteger)rowIndex
 {
 }
 
@@ -444,7 +444,7 @@ static NSString *defaultColumns = @"{ \
      toPasteboard:(NSPasteboard *)pboard
 {
   NSMutableArray *paths = [NSMutableArray array];
-  int i;
+  NSUInteger i;
 
   for (i = 0; i < [rows count]; i++) {
     int index = [[rows objectAtIndex: i] intValue];
@@ -462,7 +462,7 @@ static NSString *defaultColumns = @"{ \
 
 - (NSDragOperation)tableView:(NSTableView *)tableView 
                 validateDrop:(id <NSDraggingInfo>)info 
-                 proposedRow:(int)row 
+                 proposedRow:(NSInteger)row 
        proposedDropOperation:(NSTableViewDropOperation)operation
 {
   return NSDragOperationNone;
@@ -470,7 +470,7 @@ static NSString *defaultColumns = @"{ \
 
 - (BOOL)tableView:(NSTableView *)tableView 
        acceptDrop:(id <NSDraggingInfo>)info 
-              row:(int)row 
+              row:(NSInteger)row 
     dropOperation:(NSTableViewDropOperation)operation
 {
   return NO;
@@ -485,7 +485,7 @@ static NSString *defaultColumns = @"{ \
 }
 
 - (BOOL)tableView:(NSTableView *)aTableView 
-  shouldSelectRow:(int)rowIndex
+  shouldSelectRow:(NSInteger)rowIndex
 {
   return ((rowIndex != -1) 
                 && ([[nodeReps objectAtIndex: rowIndex] isLocked] == NO));
@@ -494,7 +494,7 @@ static NSString *defaultColumns = @"{ \
 - (void)tableView:(NSTableView *)aTableView 
   willDisplayCell:(id)aCell 
    forTableColumn:(NSTableColumn *)aTableColumn 
-              row:(int)rowIndex
+              row:(NSInteger)rowIndex
 {
   int ident = [[aTableColumn identifier] intValue];
   FSNTextCell *cell = (FSNTextCell *)[aTableColumn dataCell];
@@ -564,7 +564,7 @@ static NSString *defaultColumns = @"{ \
 
 - (BOOL)tableView:(NSTableView *)aTableView 
             shouldEditTableColumn:(NSTableColumn *)aTableColumn 
-                              row:(int)rowIndex
+                              row:(NSInteger)rowIndex
 {
   return NO;
 }
@@ -581,7 +581,7 @@ static NSString *defaultColumns = @"{ \
   NSDictionary *colsDescr;
   NSArray *nodes;
   BOOL keepinfo;
-  int i;
+  NSUInteger i;
   
   keepinfo = (node && ([self keepsColumnsInfo] || [node isEqual: anode]));
   
@@ -1571,7 +1571,7 @@ static NSString *defaultColumns = @"{ \
 - (NSDragOperation)listViewDraggingEntered:(id <NSDraggingInfo>)sender
 {
   NSPoint location;
-  int row;
+  NSInteger row;
   
   isDragTarget = NO;
   dndTarget = nil;
@@ -1599,13 +1599,13 @@ static NSString *defaultColumns = @"{ \
   }     
 
   if (dragOperation == NSDragOperationNone) {
-	  NSPasteboard *pb;
+    NSPasteboard *pb;
     NSDragOperation sourceDragMask;
-	  NSArray *sourcePaths;
+    NSArray *sourcePaths;
     NSString *basePath;
     NSString *nodePath;
     NSString *prePath;
-	  int count;
+    NSUInteger count;
 
     dndTarget = nil;
     isDragTarget = NO;
@@ -1665,13 +1665,13 @@ static NSString *defaultColumns = @"{ \
 
     if ([node isDirectory] && [node isParentOfPath: basePath]) {
       NSArray *subNodes = [node subNodes];
-      int i;
+      NSUInteger i;
 
       for (i = 0; i < [subNodes count]; i++) {
         FSNode *nd = [subNodes objectAtIndex: i];
 
         if ([nd isDirectory]) {
-          int j;
+          NSUInteger j;
 
           for (j = 0; j < count; j++) {
             NSString *fname = [[sourcePaths objectAtIndex: j] lastPathComponent];
@@ -2137,11 +2137,11 @@ static NSString *defaultColumns = @"{ \
   [self setLocked: [node isLocked]];
 }
 
-- (void)setGridIndex:(int)index
+- (void)setGridIndex:(NSUInteger)index
 {
 }
 
-- (int)gridIndex
+- (NSUInteger)gridIndex
 {
   return 0;
 }
