@@ -1,6 +1,6 @@
 /* Dock.m
  *  
- * Copyright (C) 2005-2010 Free Software Foundation, Inc.
+ * Copyright (C) 2005-2012 Free Software Foundation, Inc.
  *
  * Author: Enrico Sersale <enrico@imago.ro>
  * Date: January 2005
@@ -22,13 +22,14 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111 USA.
  */
 
-#include <Foundation/Foundation.h>
-#include <AppKit/AppKit.h>
 #include <math.h>
-#include "Dock.h"
-#include "DockIcon.h"
-#include "GWDesktopView.h"
-#include "GWorkspace.h"
+
+#import <Foundation/Foundation.h>
+#import <AppKit/AppKit.h>
+#import "Dock.h"
+#import "DockIcon.h"
+#import "GWDesktopView.h"
+#import "GWorkspace.h"
 
 #define MAX_ICN_SIZE 48
 #define MIN_ICN_SIZE 16
@@ -40,26 +41,32 @@
 {
   RELEASE (icons);
   RELEASE (backColor);
-  RELEASE (backImage);
   
   [super dealloc];
 }
 
 - (id)initForManager:(id)mngr
 {
-	self = [super initWithFrame: NSMakeRect(0, 0, 64, 64)];
+  self = [super initWithFrame: NSMakeRect(0, 0, 64, 64)];
   
-  if (self) {
-	  NSUserDefaults *defaults = [NSUserDefaults standardUserDefaults];	
-    NSDictionary *appsdict;
-    NSArray *pbTypes;
-    int i;
+  if (self)
+    {
+      NSUserDefaults *defaults = [NSUserDefaults standardUserDefaults];	
+      NSDictionary *appsdict;
+      NSArray *pbTypes;
+      int i;
+      id defEntry;
 
-    manager = mngr;
-    position = [manager dockPosition];
-    
+      manager = mngr;
+      position = [manager dockPosition];
+      
+      defEntry = [defaults objectForKey: @"dockstyle"];
+      style = DockStyleClassic;
+      if ([defEntry intValue] == DockStyleModern)
+	style = DockStyleModern;
+ 
     gw = [GWorkspace gworkspace];
-    fm = [NSFileManager defaultManager];    
+    fm = [NSFileManager defaultManager];
     ws = [NSWorkspace sharedWorkspace];
 
     icons = [NSMutableArray new];
@@ -76,8 +83,11 @@
                                          nil];
     [self registerForDraggedTypes: pbTypes];    
 
-    [self setBackColor: [[manager desktopView] currentColor]];
-    
+    if (style == DockStyleModern)
+      [self setBackColor: [[NSColor grayColor] colorWithAlphaComponent: 0.33]];
+    else
+      [self setBackColor: [NSColor grayColor]];
+      
     [self createWorkspaceIcon];
 
     appsdict = [defaults objectForKey: @"applications"];
@@ -126,7 +136,6 @@
                                appName: wsname
                               iconSize: iconSize];
   [icon setHighlightColor: backColor];
-  [icon setUseHlightImage: useBackImage];
   [icon setWsIcon: YES];   
   [icon setDocked: YES];   
   [icons insertObject: icon atIndex: 0];
@@ -143,7 +152,6 @@
                                         iconSize: iconSize];
 
   [icon setHighlightColor: backColor];
-  [icon setUseHlightImage: useBackImage];  
   [icon setTrashIcon: YES];  
   [icon setDocked: YES];                         
   [icons insertObject: icon atIndex: [icons count]];
@@ -173,7 +181,6 @@
       }
 
       [icon setHighlightColor: backColor];
-      [icon setUseHlightImage: useBackImage];
       [icons insertObject: icon atIndex: icnindex];
       [self addSubview: icon];
       RELEASE (icon);
@@ -388,6 +395,27 @@
   [self tile];
 }
 
+- (void)setStyle:(DockStyle)s
+{
+  if(style != s)
+    {
+      if (s == DockStyleClassic)
+	{
+	  [self setBackColor: [NSColor grayColor]];
+	}
+      else if (s == DockStyleModern)
+	{
+	  [self setBackColor: [[NSColor grayColor] colorWithAlphaComponent: 0.33]];
+	}
+    }
+  style = s;
+}
+
+- (DockStyle)style
+{
+  return style;
+}
+
 - (void)setBackColor:(NSColor *)color
 {
   NSColor *hlgtcolor = [color highlightWithLevel: 0.2];
@@ -403,42 +431,6 @@
   }
 }
 
-- (void)setBackImage
-{
-  NSImage *image = [[manager desktopView] backImage];
-  int i;
-
-  DESTROY (backImage);
-
-  if (image) {
-    NSRect r = [self bounds];
-    
-    backImage = [[NSImage alloc] initWithSize: r.size];
-    [backImage lockFocus]; 
-    [image compositeToPoint: NSZeroPoint 
-                   fromRect: r
-                  operation: NSCompositeCopy];
-    [backImage unlockFocus];
-    [self setNeedsDisplay: YES];
-  }
-  
-  for (i = 0; i < [icons count]; i++) {
-    [[icons objectAtIndex: i] setHighlightImage: backImage];
-  }
-}
-
-- (void)setUseBackImage:(BOOL)value
-{
-  int i;
-
-  for (i = 0; i < [icons count]; i++) {
-    [[icons objectAtIndex: i] setUseHlightImage: value];
-  }
-  
-  useBackImage = value;
-  [self setNeedsDisplay: YES];
-}
-
 - (void)tile
 {
   NSView *view = [self superview];
@@ -480,13 +472,12 @@
 
   rect.size.width = icnrect.size.width;
   rect.origin.x = (position == DockPositionLeft) ? 0 : scrrect.size.width - rect.size.width;
-  rect.origin.y = (scrrect.size.height - rect.size.height) / 2;
+  rect.origin.y = ceil((scrrect.size.height - rect.size.height) / 2);
   
   if (view) {
     [view setNeedsDisplayInRect: [self frame]];
   }
   [self setFrame: rect];
-  [self setBackImage];
   
   icnrect.origin.y = rect.size.height;
   
@@ -499,7 +490,6 @@
     
     icnrect.origin.y -= icnrect.size.height;
     [icon setFrame: icnrect];
-    [icon setHighlightImage: backImage];
     
     if ((targetIndex != -1) && (targetIndex == i)) {
       icnrect.origin.y -= icnrect.size.height;
@@ -519,14 +509,19 @@
   NSMutableDictionary *dict = [NSMutableDictionary dictionary];
   int i;  
 
-  for (i = 0; i < [icons count]; i++) {
-    DockIcon *icon = [icons objectAtIndex: i];    
+  [defaults setObject: [NSNumber numberWithInt: style]
+               forKey: @"dockstyle"];
 
-    if (([icon isSpecialIcon] == NO) && [icon isDocked]) {
-      [dict setObject: [icon appName] forKey: [NSNumber numberWithInt: i]];
-      [manager removeWatcherForPath: [[icon node] path]];
+  for (i = 0; i < [icons count]; i++)
+    {
+      DockIcon *icon = [icons objectAtIndex: i];    
+
+      if (([icon isSpecialIcon] == NO) && [icon isDocked])
+	{
+	  [dict setObject: [icon appName] forKey: [[NSNumber numberWithInt: i] stringValue]];
+	  [manager removeWatcherForPath: [[icon node] path]];
+	}
     }
-  }
 
   [defaults setObject: dict forKey: @"applications"];
   
@@ -548,10 +543,6 @@
   
   [backColor set];
   NSRectFill(rect);
-  
-  if (backImage && useBackImage) {
-    [backImage dissolveToPoint: NSZeroPoint fraction: 0.5];
-  }
 }
 
 @end
@@ -744,9 +735,8 @@
   NSColor *hlgtcolor = [acolor highlightWithLevel: 0.2];
   int i;
   
-  for (i = 0; i < [icons count]; i++) {
+  for (i = 0; i < [icons count]; i++)
     [[icons objectAtIndex: i] setHighlightColor: hlgtcolor];
-  }
   
   ASSIGN (backColor, hlgtcolor);
   if ([self superview]) {
