@@ -1,8 +1,9 @@
 /* GWDesktopView.m
  *  
- * Copyright (C) 2005-2010 Free Software Foundation, Inc.
+ * Copyright (C) 2005-2012 Free Software Foundation, Inc.
  *
  * Author: Enrico Sersale <enrico@imago.ro>
+ *         Riccardo Mottola <rm@gnu.org>
  * Date: January 2005
  *
  * This file is part of the GNUstep GWorkspace application
@@ -21,16 +22,18 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111 USA.
  */
- 
-#include <Foundation/Foundation.h>
-#include <AppKit/AppKit.h>
+
 #include <math.h>
-#include "FSNodeRep.h"
-#include "FSNFunctions.h"
-#include "GWDesktopView.h"
-#include "GWDesktopIcon.h"
-#include "GWDesktopManager.h"
-#include "Dock.h"
+
+#import <Foundation/Foundation.h>
+#import <AppKit/AppKit.h>
+#import <GNUstepGUI/GSVersion.h>
+#import "FSNodeRep.h"
+#import "FSNFunctions.h"
+#import "GWDesktopView.h"
+#import "GWDesktopIcon.h"
+#import "GWDesktopManager.h"
+#import "Dock.h"
 
 #define DEF_ICN_SIZE 48
 #define DEF_TEXT_SIZE 12
@@ -563,11 +566,13 @@
 {
   NSUserDefaults *defaults = [NSUserDefaults standardUserDefaults];	
   NSMutableDictionary *indexes = [NSMutableDictionary dictionary];
+  NSColor *tempColor;
   NSMutableDictionary *backColorDict = [NSMutableDictionary dictionary];
-  float red, green, blue, alpha;
+  CGFloat red, green, blue, alpha;
   int i;
 
-  [backColor getRed: &red green: &green blue: &blue alpha: &alpha];
+  tempColor = [backColor colorUsingColorSpaceName: NSCalibratedRGBColorSpace];
+  [tempColor getRed: &red green: &green blue: &blue alpha: &alpha];
   [backColorDict setObject: [NSNumber numberWithFloat: red] forKey: @"red"];
   [backColorDict setObject: [NSNumber numberWithFloat: green] forKey: @"green"];
   [backColorDict setObject: [NSNumber numberWithFloat: blue] forKey: @"blue"];
@@ -752,6 +757,20 @@
 	}
 }
 
+#define SUPPORTS_XOR ((GNUSTEP_GUI_MAJOR_VERSION > 0)		\
+		      || (GNUSTEP_GUI_MAJOR_VERSION == 0	\
+			  && GNUSTEP_GUI_MINOR_VERSION > 22)	\
+		      || (GNUSTEP_GUI_MAJOR_VERSION == 0	\
+			  && GNUSTEP_GUI_MINOR_VERSION == 22	\
+			  && GNUSTEP_GUI_SUBMINOR_VERSION > 0))
+
+static void GWHighlightFrameRect(NSRect aRect)
+{
+#if SUPPORTS_XOR
+  NSFrameRectWithWidthUsingOperation(aRect, 1.0, GSCompositeHighlight);
+#endif
+}
+
 - (void)mouseDragged:(NSEvent *)theEvent
 {
   unsigned int eventMask = NSLeftMouseUpMask | NSLeftMouseDraggedMask;
@@ -762,13 +781,18 @@
   float x, y, w, h;
   int i;
 
+  transparentSelection = NO;
+  if ([[manager dock] style] == DockStyleModern)
+    transparentSelection = YES;
+
   locp = [theEvent locationInWindow];
   locp = [self convertPoint: locp fromView: nil];
   startp = locp;
 
   oldRect = NSZeroRect;  
 
-	[[self window] disableFlushWindow];
+  [[self window] disableFlushWindow];
+
   [self lockFocus];
 
   while ([theEvent type] != NSLeftMouseUp) {
@@ -779,58 +803,39 @@
     locp = [theEvent locationInWindow];
     locp = [self convertPoint: locp fromView: nil];
     
-    x = (locp.x >= startp.x) ? startp.x : locp.x;
-    y = (locp.y >= startp.y) ? startp.y : locp.y;
-    w = max(locp.x, startp.x) - min(locp.x, startp.x);
-    w = (w == 0) ? 1 : w;
-    h = max(locp.y, startp.y) - min(locp.y, startp.y);
-    h = (h == 0) ? 1 : h;
+    x = min(startp.x, locp.x);
+    y = min(startp.y, locp.y);
+    w = max(1, max(locp.x, startp.x) - min(locp.x, startp.x));
+    h = max(1, max(locp.y, startp.y) - min(locp.y, startp.y));
 
     r = NSMakeRect(x, y, w, h);
     
-    if (NSEqualRects(oldRect, NSZeroRect) == NO) {
-		  [verticalImage compositeToPoint: NSMakePoint(NSMinX(oldRect), NSMinY(oldRect))
-		                         fromRect: NSMakeRect(0.0, 0.0, 1.0, oldRect.size.height)
-		                        operation: NSCompositeCopy];
+    
+    // Erase the previous rect
 
-		  [verticalImage compositeToPoint: NSMakePoint(NSMaxX(oldRect)-1, NSMinY(oldRect))
-		                         fromRect: NSMakeRect(1.0, 0.0, 1.0, oldRect.size.height)
-		                        operation: NSCompositeCopy];
+    if (transparentSelection || !SUPPORTS_XOR)
+      {
+	[self setNeedsDisplayInRect: oldRect];
+	[[self window] displayIfNeeded];
+      }
+    else
+      GWHighlightFrameRect(oldRect);
 
-		  [horizontalImage compositeToPoint: NSMakePoint(NSMinX(oldRect), NSMinY(oldRect))
-		                           fromRect: NSMakeRect(0.0, 0.0, oldRect.size.width, 1.0)
-		                          operation: NSCompositeCopy];
+    // Draw the new rect
 
-      [horizontalImage compositeToPoint: NSMakePoint(NSMinX(oldRect), NSMaxY(oldRect)-1)
-		                           fromRect: NSMakeRect(0.0, 1.0, oldRect.size.width, 1.0)
-		                          operation: NSCompositeCopy];
-    }
-    [self displayIfNeeded];
+    if (transparentSelection || !SUPPORTS_XOR)
+      {
+	[[NSColor darkGrayColor] set];
+	NSFrameRect(r);
+	if (transparentSelection)
+	  {
+	    [[[NSColor darkGrayColor] colorWithAlphaComponent: 0.33] set];
+	    NSRectFillUsingOperation(r, NSCompositeSourceOver);
+	  }
+      }
+    else
+      GWHighlightFrameRect(r);
 
-    [verticalImage lockFocus];
-    NSCopyBits([[self window] gState], 
-            NSMakeRect(NSMinX(r), NSMinY(r), 
-                          1.0, r.size.height),
-			                          NSMakePoint(0.0, 0.0));
-    NSCopyBits([[self window] gState],
-			      NSMakeRect(NSMaxX(r) -1, NSMinY(r),
-				                  1.0, r.size.height),
-			                          NSMakePoint(1.0, 0.0));
-    [verticalImage unlockFocus];
-
-    [horizontalImage lockFocus];
-    NSCopyBits([[self window] gState],
-			      NSMakeRect(NSMinX(r), NSMinY(r),
-				                  r.size.width, 1.0),
-			                          NSMakePoint(0.0, 0.0));
-    NSCopyBits([[self window] gState],
-			      NSMakeRect(NSMinX(r), NSMaxY(r) -1,
-				                  r.size.width, 1.0),
-			                          NSMakePoint(0.0, 1.0));
-    [horizontalImage unlockFocus];
-
-    [[NSColor darkGrayColor] set];
-    NSFrameRect(r);
     oldRect = r;
 
     [[self window] enableFlushWindow];
@@ -840,39 +845,24 @@
     DESTROY (arp);
   }
 
+  [self unlockFocus];
+
   [[self window] postEvent: theEvent atStart: NO];
   
-  if (NSEqualRects(oldRect, NSZeroRect) == NO) {
-		[verticalImage compositeToPoint: NSMakePoint(NSMinX(oldRect), NSMinY(oldRect))
-		                       fromRect: NSMakeRect(0.0, 0.0, 1.0, oldRect.size.height)
-		                      operation: NSCompositeCopy];
+  // Erase the previous rect
+  [self setNeedsDisplayInRect: oldRect];
+  [[self window] displayIfNeeded];
 
-		[verticalImage compositeToPoint: NSMakePoint(NSMaxX(oldRect)-1, NSMinY(oldRect))
-		                       fromRect: NSMakeRect(1.0, 0.0, 1.0, oldRect.size.height)
-		                      operation: NSCompositeCopy];
-
-		[horizontalImage compositeToPoint: NSMakePoint(NSMinX(oldRect), NSMinY(oldRect))
-		                         fromRect: NSMakeRect(0.0, 0.0, oldRect.size.width, 1.0)
-		                        operation: NSCompositeCopy];
-
-    [horizontalImage compositeToPoint: NSMakePoint(NSMinX(oldRect), NSMaxY(oldRect)-1)
-		                         fromRect: NSMakeRect(0.0, 1.0, oldRect.size.width, 1.0)
-		                        operation: NSCompositeCopy];
-  }
-  
   [[self window] enableFlushWindow];
   [[self window] flushWindow];
-  [self unlockFocus];
 
   selectionMask = FSNMultipleSelectionMask;
   selectionMask |= FSNCreatingSelectionMask;
 
-  x = (locp.x >= startp.x) ? startp.x : locp.x;
-  y = (locp.y >= startp.y) ? startp.y : locp.y;
-  w = max(locp.x, startp.x) - min(locp.x, startp.x);
-  w = (w == 0) ? 1 : w;
-  h = max(locp.y, startp.y) - min(locp.y, startp.y);
-  h = (h == 0) ? 1 : h;
+  x = min(startp.x, locp.x);
+  y = min(startp.y, locp.y);
+  w = max(1, max(locp.x, startp.x) - min(locp.x, startp.x));
+  h = max(1, max(locp.y, startp.y) - min(locp.y, startp.y));
 
   r = NSMakeRect(x, y, w, h);
 
@@ -935,14 +925,86 @@
 {  
   [super drawRect: rect];
     
-  if (backImage && useBackImage) {
-    [backImage compositeToPoint: imagePoint 
-                      operation: NSCompositeSourceOver];  
-  }
-
-	if (dragIcon) {
-		[dragIcon dissolveToPoint: dragPoint fraction: 0.3];
+  if (backImage && useBackImage)
+    {
+      NSSize imsize = [backImage size];
+      
+      if ((imsize.width >= screenFrame.size.width) || (imsize.height >= screenFrame.size.height))
+	{
+	  if (backImageStyle == BackImageTileStyle)
+	    backImageStyle = BackImageCenterStyle;
 	}
+      
+      if (backImageStyle == BackImageFitStyle)
+	{
+	  [backImage drawInRect: NSMakeRect(0, 0, screenFrame.size.width, screenFrame.size.height)
+		       fromRect: NSZeroRect
+		      operation: NSCompositeSourceOver
+		       fraction: 1.0
+		 respectFlipped: YES
+			  hints: nil];
+	}
+      else if (backImageStyle == BackImageTileStyle)
+	{
+	  CGFloat x = 0;
+	  CGFloat y = screenFrame.size.width - imsize.width;
+
+	  while (y > (0 - imsize.height))
+	    {
+	      [backImage compositeToPoint: NSMakePoint(x, y) 
+				operation: NSCompositeSourceOver];
+	      x += imsize.width;
+	      if (x >= screenFrame.size.width)
+		{
+		  y -= imsize.height;
+		  x = 0;
+		}
+	    }
+	}
+      else if (backImageStyle == BackImageScaleStyle)
+	{
+	  float imRatio;
+	  float screenRatio;
+	  float scale;
+	  NSPoint imagePoint;
+
+	  imRatio = imsize.width / imsize.height;
+	  screenRatio = screenFrame.size.width / screenFrame.size.height;
+
+	  if (imRatio > screenRatio)
+	    {
+	      /* image is wider in aspect than screen */
+	      scale = imsize.width / screenFrame.size.width;
+	      imagePoint = NSMakePoint(0, (screenFrame.size.height - imsize.height/scale) / 2);
+	    }
+	  else
+	    {
+	      /* image is taller in aspect than screen */
+	      scale = imsize.height / screenFrame.size.height;
+	      imagePoint = NSMakePoint((screenFrame.size.width - imsize.width/scale) / 2, 0);
+	    }
+	  [backImage drawInRect: NSMakeRect(imagePoint.x, imagePoint.y, imsize.width / scale, imsize.height / scale)
+		       fromRect: NSZeroRect
+		      operation: NSCompositeSourceOver
+		       fraction: 1.0
+		 respectFlipped: YES
+			  hints: nil];
+
+	}
+      else
+	{
+	  NSPoint imagePoint;
+	  imagePoint = NSMakePoint((screenFrame.size.width - imsize.width) / 2, (screenFrame.size.height - imsize.height) / 2);
+
+	  [backImage compositeToPoint: imagePoint
+			    operation: NSCompositeSourceOver];
+	}
+    }
+  
+  if (dragIcon)
+    {
+      [dragIcon dissolveToPoint: dragPoint fraction: 0.3];
+    }
 }
 
 @end
@@ -1400,7 +1462,6 @@
 - (void)setBackgroundColor:(NSColor *)acolor
 {
   [super setBackgroundColor: acolor];
-  [[manager dock] setBackColor: backColor];
 }
           
 - (void)setTextColor:(NSColor *)acolor
@@ -1416,18 +1477,18 @@
 
 - (NSDragOperation)draggingEntered:(id <NSDraggingInfo>)sender
 {
-	NSPasteboard *pb;
+  NSPasteboard *pb;
   NSDragOperation sourceDragMask;
-	NSArray *sourcePaths;
+  NSArray *sourcePaths;
   NSString *basePath;
   NSString *nodePath;
   NSString *prePath;
-	int count;
+  int count;
   int i;
   
-	isDragTarget = NO;	
-    
- 	pb = [sender draggingPasteboard];
+  isDragTarget = NO;	
+	
+  pb = [sender draggingPasteboard];
 
   if (pb && [[pb types] containsObject: NSFilenamesPboardType]) {
     sourcePaths = [pb propertyListForType: NSFilenamesPboardType]; 
@@ -1826,64 +1887,11 @@ int sortDragged(id icn1, id icn2, void *context)
   ASSIGN (backColor, color);
   [[self window] setBackgroundColor: backColor];
   [self setNeedsDisplay: YES];
-  [[manager dock] setBackColor: backColor];
 }
 
 - (void)createBackImage:(NSImage *)image
 {
-  CREATE_AUTORELEASE_POOL (pool);
-  NSSize imsize = [image size];
-  
-  if ((imsize.width >= screenFrame.size.width)
-                      || (imsize.height >= screenFrame.size.height)) {
-    if (backImageStyle == BackImageTileStyle) {  
-      backImageStyle = BackImageCenterStyle;
-    }
-  }
-  
-  if (backImageStyle == BackImageFitStyle) {
-    NSImage *newImage = [[NSImage alloc] initWithSize: screenFrame.size];
-  
-	  [image setScalesWhenResized: YES];
-	  [image setSize: screenFrame.size];
-    imagePoint = NSZeroPoint;
-    [newImage lockFocus];
-	  [image compositeToPoint: imagePoint operation: NSCompositeCopy];    
-    [newImage unlockFocus];
-    ASSIGN (backImage, newImage);
-    RELEASE (newImage);
-    
-  } else if (backImageStyle == BackImageTileStyle) {
-    NSImage *newImage = [[NSImage alloc] initWithSize: screenFrame.size];
-    float x = 0;
-    float y = screenFrame.size.width - imsize.width;
-
-    [newImage lockFocus];
-
-    while (y > (0 - imsize.height)) {
-      [image compositeToPoint: NSMakePoint(x, y) 
-                    operation: NSCompositeCopy];
-      x += imsize.width;
-      if (x >= screenFrame.size.width) {
-        y -= imsize.height;
-        x = 0;
-      }
-    }
-
-    [newImage unlockFocus];
-    
-    imagePoint = NSZeroPoint;
-    ASSIGN (backImage, newImage);
-    RELEASE (newImage);
-    
-  } else {
-    imagePoint.x = ((screenFrame.size.width - imsize.width) / 2);
-    imagePoint.y = ((screenFrame.size.height - imsize.height) / 2);
-    ASSIGN (backImage, image);
-  }
-  
-  [[manager dock] setBackImage];
-  RELEASE (pool);
+  ASSIGN(backImage, image);
 }
 
 - (NSImage *)backImage
@@ -1919,7 +1927,6 @@ int sortDragged(id icn1, id icn2, void *context)
 {
   useBackImage = value;
   [self setNeedsDisplay: YES];
-  [[manager dock] setUseBackImage: useBackImage];  
 }
 
 - (BackImageStyle)backImageStyle
