@@ -1,6 +1,6 @@
 /* GWViewerIconsView.m
  *  
- * Copyright (C) 2004 Free Software Foundation, Inc.
+ * Copyright (C) 2004-2012 Free Software Foundation, Inc.
  *
  * Author: Enrico Sersale <enrico@imago.ro>
  * Date: June 2004
@@ -22,12 +22,12 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111 USA.
  */
 
-#include <AppKit/AppKit.h>
-#include "GWViewerIconsView.h"
-#include "FSNIcon.h"
-#include "GWSpatialViewer.h"
-#include "GWViewer.h"
-#include "GWViewersManager.h"
+#import <AppKit/AppKit.h>
+#import "GWViewerIconsView.h"
+#import "FSNIcon.h"
+#import "GWSpatialViewer.h"
+#import "GWViewer.h"
+#import "GWViewersManager.h"
 
 @implementation GWViewerIconsView
 
