@@ -1,6 +1,6 @@
 /* GWViewerListView.m
  *  
- * Copyright (C) 2004 Free Software Foundation, Inc.
+ * Copyright (C) 2004-2012 Free Software Foundation, Inc.
  *
  * Author: Enrico Sersale <enrico@imago.ro>
  * Date: December 2004
@@ -22,12 +22,12 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111 USA.
  */
 
-#include <AppKit/AppKit.h>
-#include "GWViewerListView.h"
-#include "GWSpatialViewer.h"
-#include "GWViewer.h"
-#include "GWViewersManager.h"
-#include "GWorkspace.h"
+#import <AppKit/AppKit.h>
+#import "GWViewerListView.h"
+#import "GWSpatialViewer.h"
+#import "GWViewer.h"
+#import "GWViewersManager.h"
+#import "GWorkspace.h"
 
 @implementation GWViewerListViewDataSource
 
