@@ -1,6 +1,6 @@
 /* GWViewerPathsPopUp.m
  *  
- * Copyright (C) 2004-2010 Free Software Foundation, Inc.
+ * Copyright (C) 2004-2012 Free Software Foundation, Inc.
  *
  * Author: Enrico Sersale <enrico@imago.ro>
  * Date: June 2004
@@ -22,10 +22,11 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111 USA.
  */
 
-#include <Foundation/Foundation.h>
-#include <AppKit/AppKit.h>
-#include "FSNode.h"
-#include "GWViewerPathsPopUp.h"
+#import <Foundation/Foundation.h>
+#import <AppKit/AppKit.h>
+
+#import "FSNode.h"
+#import "GWViewerPathsPopUp.h"
 
 @implementation GWViewerPathsPopUp
 
