@@ -1,6 +1,6 @@
 /* GWViewerShelf.h
  *  
- * Copyright (C) 2004 Free Software Foundation, Inc.
+ * Copyright (C) 2004-2012 Free Software Foundation, Inc.
  *
  * Author: Enrico Sersale <enrico@imago.ro>
  * Date: July 2004
@@ -22,12 +22,9 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111 USA.
  */
 
-#ifndef GWVIEWER_SHELF_H
-#define GWVIEWER_SHELF_H
-
-#include <Foundation/Foundation.h>
-#include <AppKit/NSView.h>
-#include "FSNodeRep.h"
+#import <Foundation/Foundation.h>
+#import <AppKit/NSView.h>
+#import "FSNodeRep.h"
 
 @class NSTextField;
 @class GWorkspace;
@@ -135,6 +132,7 @@
 - (void)repSelected:(id)arep;
 - (void)unselectOtherReps:(id)arep;
 - (NSArray *)selectedPaths;  
+- (void)openSelectionInNewViewer:(BOOL)newv;
 
 - (void)nodeContentsWillChange:(NSDictionary *)info;
 - (void)nodeContentsDidChange:(NSDictionary *)info;
@@ -169,5 +167,5 @@
 
 @end
 
-#endif // GWVIEWER_SHELF_H
+
 
