@@ -1,6 +1,6 @@
 /* Finder.m
  *  
- * Copyright (C) 2005-2010 Free Software Foundation, Inc.
+ * Copyright (C) 2005-2013 Free Software Foundation, Inc.
  *
  * Author: Enrico Sersale <enrico@imago.ro>
  * Date: January 2005
@@ -86,7 +86,7 @@ static Finder *finder = nil;
     NSArray *usedModules;
     NSRect rect;
     NSSize cs, ms;
-    int i;
+    NSUInteger i;
     
     if ([NSBundle loadNibNamed: nibName owner: self] == NO) {
       NSLog(@"failed to load %@!", nibName);
@@ -121,16 +121,16 @@ static Finder *finder = nil;
     RELEASE (placesScroll);  
   
     placesMatrix = [[NSMatrix alloc] initWithFrame: NSMakeRect(0, 0, 100, 100)
-				            	              mode: NSListModeMatrix 
-                               prototype: [[SearchPlacesCell new] autorelease]
-			       							  numberOfRows: 0 
-                         numberOfColumns: 0];
+                                              mode: NSListModeMatrix 
+                                         prototype: [[SearchPlacesCell new] autorelease]
+                                      numberOfRows: 0 
+                                   numberOfColumns: 0];
     [placesMatrix setTarget: self];
     [placesMatrix setAction: @selector(placesMatrixAction:)];
     [placesMatrix setIntercellSpacing: NSZeroSize];
     [placesMatrix setCellSize: NSMakeSize(1, CELLS_HEIGHT)];
     [placesMatrix setAutoscroll: YES];
-	  [placesMatrix setAllowsEmptySelection: YES];
+    [placesMatrix setAllowsEmptySelection: YES];
     cs = [placesScroll contentSize];
     ms = [placesMatrix cellSize];
     ms.width = cs.width;
@@ -256,8 +256,8 @@ static Finder *finder = nil;
   NSMutableArray *unsortedModules;
   NSDictionary *lastUsedModules;
   NSArray *usedNames;
-  int index;
-  int i;
+  NSUInteger index;
+  NSUInteger i;
 
   bundlesPaths = [NSMutableArray array];
   enumerator = [NSSearchPathForDirectoriesInDomains
@@ -279,24 +279,26 @@ static Finder *finder = nil;
 
   unsortedModules = [NSMutableArray array];
 
-  for (i = 0; i < [bundlesPaths count]; i++) {
-    CREATE_AUTORELEASE_POOL(arp);
-    NSString *bpath = [bundlesPaths objectAtIndex: i];
-    NSBundle *bundle = [NSBundle bundleWithPath: bpath];
+  for (i = 0; i < [bundlesPaths count]; i++)
+    {
+      CREATE_AUTORELEASE_POOL(arp);
+      NSString *bpath = [bundlesPaths objectAtIndex: i];
+      NSBundle *bundle = [NSBundle bundleWithPath: bpath];
      
-    if (bundle) {
-			Class principalClass = [bundle principalClass];
+      if (bundle)
+        {
+          Class principalClass = [bundle principalClass];
 
-			if ([principalClass conformsToProtocol: @protocol(FinderModulesProtocol)]) {	
-        id module = [[principalClass alloc] initInterface];
+          if ([principalClass conformsToProtocol: @protocol(FinderModulesProtocol)]) {	
+            id module = [[principalClass alloc] initInterface];
         
-        [unsortedModules addObject: module];
-	  		RELEASE ((id)module);			
-			}
-    }
+            [unsortedModules addObject: module];
+            RELEASE ((id)module);			
+          }
+        }
     
-    RELEASE (arp);
-  }
+      RELEASE (arp);
+    }
 
   if ([unsortedModules count] == 0) {  
     NSRunAlertPanel(NSLocalizedString(@"error", @""), 
@@ -350,7 +352,7 @@ static Finder *finder = nil;
 - (NSArray *)usedModules
 {
   NSMutableArray *used = [NSMutableArray array];
-  int i;
+  NSUInteger i;
 
   for (i = 0; i < [modules count]; i++) {
     id module = [modules objectAtIndex: i];
@@ -365,7 +367,7 @@ static Finder *finder = nil;
 
 - (id)firstUnusedModule
 {
-  int i;
+  NSUInteger i;
   
   for (i = 0; i < [modules count]; i++) {
     id module = [modules objectAtIndex: i];
@@ -380,7 +382,7 @@ static Finder *finder = nil;
 
 - (id)moduleWithName:(NSString *)mname
 {
-  int i;
+  NSUInteger i;
   
   for (i = 0; i < [modules count]; i++) {
     id module = [modules objectAtIndex: i];
@@ -401,8 +403,8 @@ static Finder *finder = nil;
     int index = [fmviews indexOfObjectIdenticalTo: aview];  
     id module = [self firstUnusedModule];
     id fmview = [[FindModuleView alloc] initWithDelegate: self];
-    int count;
-    int i;
+    NSUInteger count;
+    NSUInteger i;
     
     [module setInUse: YES];
     [fmview setModule: module];
@@ -434,8 +436,8 @@ static Finder *finder = nil;
 - (void)removeModule:(FindModuleView *)aview
 {
   if ([fmviews count] > 1) {
-    int count;
-    int i;
+    NSUInteger count;
+    NSUInteger i;
 
     [[aview module] setInUse: NO];
     [[aview mainBox] removeFromSuperview];
@@ -464,7 +466,7 @@ static Finder *finder = nil;
   id module = [self moduleWithName: mname];
 
   if (module && ([aview module] != module)) {
-    int i;
+    NSUInteger i;
 
     [[aview module] setInUse: NO];
     [module setInUse: YES];
@@ -479,7 +481,7 @@ static Finder *finder = nil;
 - (IBAction)chooseSearchPlacesType:(id)sender
 {
   NSArray *cells = [placesMatrix cells];
-  int i;
+  NSUInteger i;
   
   usesSearchPlaces = ([sender indexOfSelectedItem] == PLACES);
   
@@ -496,43 +498,44 @@ static Finder *finder = nil;
 
 - (NSDragOperation)draggingEnteredInSearchPlaces:(id <NSDraggingInfo>)sender
 {
-  if (usesSearchPlaces) {
-	  NSPasteboard *pb = [sender draggingPasteboard];
+  if (usesSearchPlaces)
+    {
+      NSPasteboard *pb = [sender draggingPasteboard];
 
-    splacesDndTarget = NO;
+      splacesDndTarget = NO;
 
-    if ([[pb types] containsObject: NSFilenamesPboardType]) {
-	    NSArray *sourcePaths = [pb propertyListForType: NSFilenamesPboardType]; 
-      NSArray *cells = [placesMatrix cells];
-      int count = [sourcePaths count];
-      int i;
+      if ([[pb types] containsObject: NSFilenamesPboardType])
+        {
+          NSArray *sourcePaths = [pb propertyListForType: NSFilenamesPboardType]; 
+          NSArray *cells = [placesMatrix cells];
+          NSUInteger count = [sourcePaths count];
+          NSUInteger i;
 
-	    if (count == 0) {
-		    return NSDragOperationNone;
-      } 
+          if (count == 0)
+            return NSDragOperationNone;
 
-      for (i = 0; i < [cells count]; i++) {
-        SearchPlacesCell *cell = [cells objectAtIndex: i];
+          for (i = 0; i < [cells count]; i++)
+            {
+              SearchPlacesCell *cell = [cells objectAtIndex: i];
 
-        if ([sourcePaths containsObject: [cell path]]) {
-		      return NSDragOperationNone;
+              if ([sourcePaths containsObject: [cell path]])
+                return NSDragOperationNone;
+            }
+
+          splacesDndTarget = YES;    
+
+          return [sender draggingSourceOperationMask];
         }
-      }
-
-      splacesDndTarget = YES;    
-
-      return [sender draggingSourceOperationMask];
     }
-  }
     
   return NSDragOperationNone;
 }
 
 - (NSDragOperation)draggingUpdatedInSearchPlaces:(id <NSDraggingInfo>)sender
 {
-	if (splacesDndTarget && usesSearchPlaces) {
-		return [sender draggingSourceOperationMask];
-	}
+  if (splacesDndTarget && usesSearchPlaces) {
+    return [sender draggingSourceOperationMask];
+  }
   return NSDragOperationNone;
 }
 
@@ -543,7 +546,7 @@ static Finder *finder = nil;
 
     if ([[pb types] containsObject: NSFilenamesPboardType]) {
       NSArray *sourcePaths = [pb propertyListForType: NSFilenamesPboardType]; 
-      int i;  
+      NSUInteger i;  
 
       for (i = 0; i < [sourcePaths count]; i++) {
         [self addSearchPlaceWithPath: [sourcePaths objectAtIndex: i]];
@@ -556,37 +559,37 @@ static Finder *finder = nil;
 
 - (IBAction)addSearchPlaceFromDialog:(id)sender
 {
-	NSOpenPanel *openPanel;
+  NSOpenPanel *openPanel;
   NSArray *filenames;
-	int result;
-  int i;
+  NSInteger result;
+  NSUInteger i;
   
-	openPanel = [NSOpenPanel openPanel];
-	[openPanel setTitle: NSLocalizedString(@"open", @"")];	
-	[openPanel setAllowsMultipleSelection: YES];
-	[openPanel setCanChooseFiles: YES];
-	[openPanel setCanChooseDirectories: YES];
+  openPanel = [NSOpenPanel openPanel];
+  [openPanel setTitle: NSLocalizedString(@"open", @"")];	
+  [openPanel setAllowsMultipleSelection: YES];
+  [openPanel setCanChooseFiles: YES];
+  [openPanel setCanChooseDirectories: YES];
 
-	result = [openPanel runModalForDirectory: systemRoot() 
+  result = [openPanel runModalForDirectory: systemRoot() 
                                       file: nil 
-							                       types: nil];
-	if (result != NSOKButton) {
-		return;
-	}
+                                     types: nil];
+  if (result != NSOKButton)
+    return;
 	
   filenames = [openPanel filenames];
 
-  for (i = 0; i < [filenames count]; i++) {
-    [self addSearchPlaceWithPath: [filenames objectAtIndex: i]];
-  }
+  for (i = 0; i < [filenames count]; i++)
+    {
+      [self addSearchPlaceWithPath: [filenames objectAtIndex: i]];
+    }
 }
 
 - (void)addSearchPlaceWithPath:(NSString *)spath
 {
   NSArray *cells = [placesMatrix cells];  
-  int count = [cells count];
+  NSUInteger count = [cells count];
   BOOL found = NO;
-  int i;
+  NSUInteger i;
 
   for (i = 0; i < [cells count]; i++) {
     NSString *srchpath = [[cells objectAtIndex: i] path];
@@ -622,7 +625,7 @@ static Finder *finder = nil;
 - (IBAction)removeSearchPlaceButtAction:(id)sender
 {
   NSArray *cells = [placesMatrix selectedCells];
-  int i;
+  NSUInteger i;
 
   for (i = 0; i < [cells count]; i++) {
     [self removeSearchPlaceWithPath: [[cells objectAtIndex: i] path]];
@@ -632,13 +635,13 @@ static Finder *finder = nil;
 - (void)removeSearchPlaceWithPath:(NSString *)spath
 {
   NSArray *cells = [placesMatrix cells];
-  int i;
+  NSUInteger i;
 
   for (i = 0; i < [cells count]; i++) {
     SearchPlacesCell *cell = [cells objectAtIndex: i];
   
     if ([[cell path] isEqual: spath]) {
-      int row, col;
+      NSInteger row, col;
       
       [placesMatrix getRow: &row column: &col ofCell: cell];
       [placesMatrix removeRow: row];
@@ -661,7 +664,7 @@ static Finder *finder = nil;
   
   if (cells && [cells count]) {
     NSMutableArray *paths = [NSMutableArray array];  
-    int i;
+    NSUInteger i;
   
     for (i = 0; i < [cells count]; i++) {
       [paths addObject: [[cells objectAtIndex: i] path]];
@@ -679,7 +682,7 @@ static Finder *finder = nil;
   
   if (cells && [cells count]) {
     NSMutableArray *paths = [NSMutableArray array];  
-    int i;
+    NSUInteger i;
     
     RETAIN (cells);
     for (i = 0; i < [cells count]; i++) {
@@ -720,7 +723,7 @@ static Finder *finder = nil;
 {
   NSMutableDictionary *criteria = [NSMutableDictionary dictionary];
   NSArray *selection;
-  int i;
+  NSUInteger i;
 
   if (usesSearchPlaces == NO) {
     if (currentSelection == nil) {
@@ -777,7 +780,7 @@ static Finder *finder = nil;
 
 - (void)stopAllSearchs
 {
-  int i;
+  NSUInteger i;
 
   for (i = 0; i < [searchResults count]; i++) {
     SearchResults *results = [searchResults objectAtIndex: i];
@@ -791,7 +794,7 @@ static Finder *finder = nil;
 
 - (id)resultWithAddress:(unsigned long)address
 {
-  int i;
+  NSUInteger i;
 
   for (i = 0; i < [searchResults count]; i++) {
     SearchResults *results = [searchResults objectAtIndex: i];
@@ -826,7 +829,7 @@ static Finder *finder = nil;
 
 - (void)openFoundSelection:(NSArray *)selection
 {
-  int i;
+  NSUInteger i;
 
   for (i = 0; i < [selection count]; i++) {
     FSNode *node = [selection objectAtIndex: i];
@@ -850,7 +853,7 @@ static Finder *finder = nil;
 - (void)fileSystemWillChange:(NSNotification *)notif
 {
   NSDictionary *info = [notif object];
-  int i;
+  NSUInteger i;
 
   for (i = 0; i < [lsFolders count]; i++) {
     LSFolder *folder = [lsFolders objectAtIndex: i];
@@ -875,7 +878,7 @@ static Finder *finder = nil;
   NSMutableArray *srcpaths = [NSMutableArray array];
   NSMutableArray *dstpaths = [NSMutableArray array];
   BOOL copy, move, remove; 
-  int i, j, count;
+  NSUInteger i, j, count;
 
   if ([operation isEqual: @"GWorkspaceRenameOperation"])
     {
@@ -1022,9 +1025,9 @@ static Finder *finder = nil;
 {
   NSRect wrect = [win frame];
   NSRect mbrect = [modulesBox bounds];
-  int count = [fmviews count];
-  float hspace = (count * FMVIEWH) + HMARGIN + BORDER;
-  int i;
+  NSUInteger count = [fmviews count];
+  CGFloat hspace = (count * FMVIEWH) + HMARGIN + BORDER;
+  NSUInteger i;
     
   if (mbrect.size.height != hspace) {  
     if (wrect.size.height != WINH) {
@@ -1040,7 +1043,7 @@ static Finder *finder = nil;
     FindModuleView *fmview = [fmviews objectAtIndex: i];
     NSBox *fmbox = [fmview mainBox];
     NSRect mbr = [fmbox frame];
-    float posy = mbrect.size.height - (FMVIEWH * (i + 1)) - BORDER;
+    CGFloat posy = mbrect.size.height - (FMVIEWH * (i + 1)) - BORDER;
     
     if (mbr.origin.y != posy) {
       mbr.origin.y = posy;
@@ -1063,7 +1066,7 @@ static Finder *finder = nil;
   NSArray *cells = [placesMatrix cells];
   NSMutableArray *savedPlaces = [NSMutableArray array];
   NSMutableArray *lsfpaths = [NSMutableArray array];
-  int i;
+  NSUInteger i;
 
   if (cells && [cells count]) {
     for (i = 0; i < [cells count]; i++) {
@@ -1175,7 +1178,7 @@ static Finder *finder = nil;
 
 - (LSFolder *)lsfolderWithNode:(FSNode *)node
 {
-  int i;
+  NSUInteger i;
   
   for (i = 0; i < [lsFolders count]; i++) {
     LSFolder *folder = [lsFolders objectAtIndex: i];
@@ -1190,7 +1193,7 @@ static Finder *finder = nil;
 
 - (LSFolder *)lsfolderWithPath:(NSString *)path
 {
-  int i;
+  NSUInteger i;
   
   for (i = 0; i < [lsFolders count]; i++) {
     LSFolder *folder = [lsFolders objectAtIndex: i];
