@@ -1,6 +1,6 @@
 /* TShelfIcon.m
  *  
- * Copyright (C) 2003-2010 Free Software Foundation, Inc.
+ * Copyright (C) 2003-2013 Free Software Foundation, Inc.
  *
  * Author: Enrico Sersale <enrico@imago.ro>
  * Date: August 2001
@@ -60,95 +60,102 @@
        inIconsView:(TShelfIconsView *)aview
 {
   self = [super init];
-  if (self) {
-    NSFont *font;
-    NSRect hlightRect;
-    int count;
-
-    fsnodeRep = [FSNodeRep sharedInstance];
-    fm = [NSFileManager defaultManager];
-    gw = [GWorkspace gworkspace];
-
-    [self setFrame: NSMakeRect(0, 0, 64, 52)];
-		paths = [NSMutableArray new];
-		[paths addObjectsFromArray: fpaths];
-    tview = aview;  
-    labelWidth = [tview cellsWidth] - 4;
-    font = [NSFont systemFontOfSize: 12];
-    isSelect = NO; 
-    locked = NO;
-    count = [paths count];                    
-
-    if (count == 1) {
-      singlepath = YES;
-      ASSIGN (node, [FSNode nodeWithPath: [paths objectAtIndex: 0]]);
-    
-			if ([[node path] isEqual: path_separator()]) {
-				ASSIGN (name, [node path]);
-				isRootIcon = YES;
-			} else {
-    		ASSIGN (name, [node name]);
-				isRootIcon = NO;
-			}
+  if (self)
+    {
+      NSFont *font;
+      NSRect hlightRect;
+      NSUInteger count;
       
-    } else {
-      node = nil;
-      singlepath = NO;
-			isRootIcon = NO;
-      name = [[NSString alloc] initWithFormat: @"%i items", count];
+      fsnodeRep = [FSNodeRep sharedInstance];
+      fm = [NSFileManager defaultManager];
+      gw = [GWorkspace gworkspace];
+
+      paths = [NSMutableArray new];
+      [paths addObjectsFromArray: fpaths];
+      tview = aview;  
+      labelWidth = [tview cellsWidth] - 4;
+      font = [NSFont systemFontOfSize: 12];
+      isSelect = NO; 
+      locked = NO;
+
+      count = [paths count];
+      if (count == 1)
+	{
+	  singlepath = YES;
+	  ASSIGN (node, [FSNode nodeWithPath: [paths objectAtIndex: 0]]);
+	  
+	  if ([[node path] isEqual: path_separator()])
+	    {
+	      ASSIGN (name, [node path]);
+	      isRootIcon = YES;
+	    }
+	  else
+	    {
+	      ASSIGN (name, [node name]);
+	      isRootIcon = NO;
+	    }
+	}
+      else
+	{
+	  node = nil;
+	  singlepath = NO;
+	  isRootIcon = NO;
+	  name = [[NSString alloc] initWithFormat: @"%u items", count];
+	}
+      
+      if (singlepath)
+	ASSIGN (icon, [fsnodeRep iconOfSize: ICON_SIZE forNode: node]);    
+      else
+	ASSIGN (icon, [fsnodeRep multipleSelectionIconOfSize: ICON_SIZE]);
+      
+      hlightRect = NSZeroRect;
+      hlightRect.size.width = (float)ICON_SIZE / 3 * 4;
+      hlightRect.size.height = hlightRect.size.width * [fsnodeRep highlightHeightFactor];
+      if ((hlightRect.size.height - ICON_SIZE) < 4)
+	hlightRect.size.height = ICON_SIZE + 4;
+      hlightRect = NSIntegralRect(hlightRect);
+      ASSIGN (highlightPath, [fsnodeRep highlightPathOfSize: hlightRect.size]);
+      
+      if (isRootIcon)
+	{
+	  NSHost *host = [NSHost currentHost];
+	  NSString *hname = [host name];
+	  NSRange range = [hname rangeOfString: @"."];
+	  
+	  if (range.length != 0)
+	    {	
+	      hname = [hname substringToIndex: range.location];
+	    } 			
+	  ASSIGN (hostname, hname);			
+	}
+      else
+	{
+	  hostname = nil;
+	}
+      
+      namelabel = [NSTextField new];    
+      [namelabel setFont: font];
+      [namelabel setBezeled: NO];
+      [namelabel setEditable: NO];
+      [namelabel setSelectable: NO];
+      [namelabel setAlignment: NSCenterTextAlignment];
+      [namelabel setDrawsBackground: NO];
+      [namelabel setTextColor: [NSColor controlTextColor]];
+      [self setLabelWidth]; 
+      [self setFrame: NSMakeRect(0, 0, 64, 52)];
+      [self registerForDraggedTypes: [NSArray arrayWithObjects: 
+						NSFilenamesPboardType, 
+					      @"GWLSFolderPboardType", 
+					      @"GWRemoteFilenamesPboardType", 
+					      nil]];
+      
+      position = NSMakePoint(0, 0);
+      gridindex = NSNotFound;
+      dragdelay = 0;
+      isDragTarget = NO;
+      onSelf = NO;
+      trectTag = -1;
     }
-
-    if (singlepath) {
-      ASSIGN (icon, [fsnodeRep iconOfSize: ICON_SIZE forNode: node]);    
-    } else {
-      ASSIGN (icon, [fsnodeRep multipleSelectionIconOfSize: ICON_SIZE]);
-    }
-        
-    hlightRect = NSZeroRect;
-    hlightRect.size.width = (float)ICON_SIZE / 3 * 4;
-    hlightRect.size.height = hlightRect.size.width * [fsnodeRep highlightHeightFactor];
-    if ((hlightRect.size.height - ICON_SIZE) < 4) {
-      hlightRect.size.height = ICON_SIZE + 4;
-    }
-    hlightRect = NSIntegralRect(hlightRect);
-    ASSIGN (highlightPath, [fsnodeRep highlightPathOfSize: hlightRect.size]);
-
-		if (isRootIcon) {
-			NSHost *host = [NSHost currentHost];
-			NSString *hname = [host name];
-			NSRange range = [hname rangeOfString: @"."];
-
-			if (range.length != 0) {	
-				hname = [hname substringToIndex: range.location];
-			} 			
-			ASSIGN (hostname, hname);			
-  	} else {
-			hostname = nil;
-		}
-
-    namelabel = [NSTextField new];    
-		[namelabel setFont: font];
-		[namelabel setBezeled: NO];
-		[namelabel setEditable: NO];
-		[namelabel setSelectable: NO];
-		[namelabel setAlignment: NSCenterTextAlignment];
-    [namelabel setDrawsBackground: NO];
-	  [namelabel setTextColor: [NSColor controlTextColor]];
-		[self setLabelWidth]; 
-    
-    [self registerForDraggedTypes: [NSArray arrayWithObjects: 
-                                              NSFilenamesPboardType, 
-                                              @"GWLSFolderPboardType", 
-                                              @"GWRemoteFilenamesPboardType", 
-                                              nil]];
-    
-		position = NSMakePoint(0, 0);
-		gridindex = -1;
-    dragdelay = 0;
-    isDragTarget = NO;
-    onSelf = NO;
-    trectTag = -1;
-  }
   
   return self;
 }
@@ -157,32 +164,39 @@
         atPosition:(NSPoint)pos
        inIconsView:(TShelfIconsView *)aview
 {
-	[self initForPaths: fpaths inIconsView: aview];
-  position = NSMakePoint(pos.x, pos.y);
+  self = [self initForPaths: fpaths inIconsView: aview];
+  if (self)
+    {
+      position = NSMakePoint(pos.x, pos.y);
+    }
   return self;
 }
 
 - (id)initForPaths:(NSArray *)fpaths 
-				 gridIndex:(int)index
+	 gridIndex:(NSUInteger)index
        inIconsView:(TShelfIconsView *)aview
 {
-	[self initForPaths: fpaths inIconsView: aview];
-	gridindex = index;
+  self = [self initForPaths: fpaths inIconsView: aview];
+  if (self)
+    {
+      gridindex = index;
+    }
   return self;
 }
 
 - (void)setPaths:(NSArray *)fpaths
 {
-  int count;
+  NSUInteger count;
 
   RELEASE (paths);
   RELEASE (node);
-	paths = [[NSMutableArray alloc] initWithCapacity: 1];
-	[paths addObjectsFromArray: fpaths];
+  paths = [[NSMutableArray alloc] initWithCapacity: 1];
+  [paths addObjectsFromArray: fpaths];
   count = [paths count];                    
 
-  if (count == 1) {
-    singlepath = YES;
+  if (count == 1)
+    {
+      singlepath = YES;
     
     ASSIGN (node, [FSNode nodeWithPath: [paths objectAtIndex: 0]]);
 
@@ -198,7 +212,7 @@
     DESTROY (node);
     singlepath = NO;
 		isRootIcon = NO;
-    name = [[NSString alloc] initWithFormat: @"%i items", count];
+    name = [[NSString alloc] initWithFormat: @"%u items", count];
   }
 
   if (singlepath) {
@@ -230,10 +244,10 @@
   position = NSMakePoint(pos.x, pos.y);
 }
 
-- (void)setPosition:(NSPoint)pos gridIndex:(int)index
+- (void)setPosition:(NSPoint)pos gridIndex:(NSUInteger)index
 {
   position = NSMakePoint(pos.x, pos.y);
-	gridindex = index;
+  gridindex = index;
 }
 
 - (NSPoint)position
@@ -241,32 +255,33 @@
   return position;
 }
 
-- (void)setGridIndex:(int)index
+- (void)setGridIndex:(NSUInteger)index
 {
-	gridindex = index;
+  gridindex = index;
 }
 
-- (int)gridindex
+- (NSUInteger)gridindex
 {
-	return gridindex;
+  return gridindex;
 }
 
 - (void)select
 {
-	isSelect = YES;
-  if (locked == NO) {
-    [namelabel setTextColor: [NSColor controlTextColor]];
-  }
+  isSelect = YES;
+  if (locked == NO)
+    {
+      [namelabel setTextColor: [NSColor controlTextColor]];
+    }
   [self setNeedsDisplay: YES];
 }
 
 - (void)unselect
 {
-	isSelect = NO;
+  isSelect = NO;
   if (locked == NO) {
     [namelabel setTextColor: [NSColor controlTextColor]];
   }
-	[self setNeedsDisplay: YES];
+  [self setNeedsDisplay: YES];
 }
 
 - (void)renewIcon
@@ -283,9 +298,9 @@
 {
   NSFont *font = [NSFont systemFontOfSize: 12];
   NSRect rect = [namelabel frame];
-	NSString *nstr = isRootIcon ? hostname : name;
+  NSString *nstr = isRootIcon ? hostname : name;
   
-	labelWidth = [tview cellsWidth] - 8;
+  labelWidth = [tview cellsWidth] - 8;
 	  
   if (isSelect) {
     [namelabel setFrame: NSMakeRect(0, 0, [font widthOfString: nstr] + 8, 14)];
@@ -439,15 +454,16 @@
 
 - (void)drawRect:(NSRect)rect
 {
-	NSPoint p;
+  NSPoint p;
   NSSize s;
   NSSize boundsSize;
       	
-	if(isSelect) {
-    [[NSColor selectedControlColor] set];
-    [highlightPath fill];
-	}
-	
+  if(isSelect)
+    {
+      [[NSColor selectedControlColor] set];
+      [highlightPath fill];
+    }
+  
   s = [icon size];
   boundsSize = [self bounds].size;
   p = NSMakePoint((boundsSize.width - s.width) / 2, (boundsSize.height - s.height) / 2);	
@@ -521,9 +537,9 @@
 	}
 }
 
-- (unsigned int)draggingSourceOperationMaskForLocal:(BOOL)flag
+- (NSDragOperation)draggingSourceOperationMaskForLocal:(BOOL)flag
 {
-  return NSDragOperationAll;
+  return NSDragOperationEvery;
 }
 
 @end
@@ -532,18 +548,18 @@
 
 - (NSDragOperation)draggingEntered:(id <NSDraggingInfo>)sender
 {
-	NSPasteboard *pb;
+  NSPasteboard *pb;
   NSDragOperation sourceDragMask;
-	NSArray *sourcePaths;
-	NSString *fromPath;
+  NSArray *sourcePaths;
+  NSString *fromPath;
   NSString *buff;
-	unsigned i, count;
+  unsigned i, count;
 
-	CHECK_LOCK_RET (NSDragOperationNone);
-	
-	isDragTarget = NO;
-
-	pb = [sender draggingPasteboard];
+  CHECK_LOCK_RET (NSDragOperationNone);
+  
+  isDragTarget = NO;
+  
+  pb = [sender draggingPasteboard];
   sourcePaths = nil;
   
   if ([[pb types] containsObject: NSFilenamesPboardType]) {
@@ -572,53 +588,44 @@
   if ([paths isEqualToArray: sourcePaths]) {
     onSelf = YES;
     isDragTarget = YES;
-    return NSDragOperationAll;
+    return NSDragOperationEvery;
   }
   
-  if (node == nil) {
+  if (node == nil)
     return NSDragOperationNone;
-  }
   
   if ((([node isDirectory] == NO) && ([node isMountPoint] == NO)) 
                   || ([node isPackage] && ([node isApplication] == NO))) {
     return NSDragOperationNone;
   }
-
-	count = [sourcePaths count];
-	fromPath = [[sourcePaths objectAtIndex: 0] stringByDeletingLastPathComponent];
-
-	if (count == 0) {
-		return NSDragOperationNone;
-  } 
-
-	if (([node isWritable] == NO) && ([node isApplication] == NO)) {
+  
+  count = [sourcePaths count];
+  fromPath = [[sourcePaths objectAtIndex: 0] stringByDeletingLastPathComponent];
+  
+  if (count == 0)
     return NSDragOperationNone;
-	}
 
-	if ([[node path] isEqual: fromPath]) {
-		return NSDragOperationNone;
-  }  
-
-  if ([sourcePaths containsObject: [node path]]) {
+  if (([node isWritable] == NO) && ([node isApplication] == NO))
     return NSDragOperationNone;
-  }
+  
+  
+  if ([[node path] isEqual: fromPath])
+    return NSDragOperationNone;
+  
 
-	buff = [NSString stringWithString: [node path]];
-	while (1) {
-    CREATE_AUTORELEASE_POOL(arp);
+  if ([sourcePaths containsObject: [node path]])
+    return NSDragOperationNone;
 
-		for (i = 0; i < count; i++) {
-			if ([buff isEqual: [sourcePaths objectAtIndex: i]]) {
-        RELEASE (arp);
- 		    return NSDragOperationNone;
-			}
-		}
-    if ([buff isEqual: path_separator()]) {
-      RELEASE (arp);
-      break;
-    }            
-		buff = [buff stringByDeletingLastPathComponent];
-  }
+  buff = [NSString stringWithString: [node path]];
+  while (![buff isEqual: path_separator()])
+    {
+      for (i = 0; i < count; i++)
+        {
+          if ([buff isEqual: [sourcePaths objectAtIndex: i]])
+            return NSDragOperationNone;
+        }
+      buff = [buff stringByDeletingLastPathComponent];
+    }
 
   if ([node isDirectory] && [node isParentOfPath: fromPath]) {
     NSArray *subNodes = [node subNodes];
@@ -668,10 +675,10 @@
 	} else {
     if ([[NSFileManager defaultManager] isWritableFileAtPath: fromPath]
                                                   || [node isApplication]) {
-      return NSDragOperationAll;			
+      return NSDragOperationEvery;			
     } else if ([node isApplication] == NO) {
       forceCopy = YES;
-			return NSDragOperationCopy;			
+      return NSDragOperationCopy;			
     }
 	}
   
@@ -698,7 +705,7 @@
 	} else if (sourceDragMask == NSDragOperationLink) {
 		return ([node isApplication] ? NSDragOperationMove : NSDragOperationLink);
 	} else {
-		return forceCopy ? NSDragOperationCopy : NSDragOperationAll;
+		return forceCopy ? NSDragOperationCopy : NSDragOperationEvery;
 	}
 
 	return NSDragOperationNone;
@@ -730,13 +737,13 @@
 
 - (void)concludeDragOperation:(id <NSDraggingInfo>)sender
 {
-	NSPasteboard *pb;
+  NSPasteboard *pb;
   NSDragOperation sourceDragMask;
-	NSArray *sourcePaths;
+  NSArray *sourcePaths;
   NSString *operation, *source;
   NSMutableArray *files;
   NSMutableDictionary *opDict;
-  int i;
+  NSUInteger i;
 
   isDragTarget = NO;
 
