@@ -1,6 +1,6 @@
 /* TShelfIconsView.m
  *  
- * Copyright (C) 2003-2010 Free Software Foundation, Inc.
+ * Copyright (C) 2003-2013 Free Software Foundation, Inc.
  *
  * Author: Enrico Sersale <enrico@imago.ro>
  * Date: August 2001
@@ -50,13 +50,18 @@
 
 - (NSComparisonResult)iconCompare:(id)other
 {
-	if ([other gridindex] > [self gridindex]) {
-		return NSOrderedAscending;	
-	} else {
-		return NSOrderedDescending;	
-	}
+  if ([other gridindex] == [self gridindex])
+    return NSOrderedSame;
 
-	return NSOrderedSame;
+  if ([other gridindex] == NSNotFound)
+    return NSOrderedAscending;
+  if ([self gridindex] == NSNotFound)
+    return NSOrderedDescending;
+
+  if ([other gridindex] > [self gridindex])
+    return NSOrderedAscending;	
+  
+  return NSOrderedDescending;	
 }
 
 @end
@@ -71,13 +76,18 @@
 
 - (NSComparisonResult)pbiconCompare:(id)other
 {
-	if ([other gridindex] > [self gridindex]) {
-		return NSOrderedAscending;	
-	} else {
-		return NSOrderedDescending;	
-	}
+  if ([other gridindex] == [self gridindex])
+    return NSOrderedSame;
 
-	return NSOrderedSame;
+  if ([other gridindex] == NSNotFound)
+    return NSOrderedAscending;
+  if ([self gridindex] == NSNotFound)
+    return NSOrderedDescending;
+
+  if ([other gridindex] > [self gridindex])
+    return NSOrderedAscending;	
+  
+  return NSOrderedDescending;	
 }
 
 @end
@@ -102,116 +112,130 @@
                      iconsType:(int)itype
                       lastView:(BOOL)last
 {	
-	self = [super init];
+  self = [super init];
   
-  if (self) {
-    NSArray *hiddenPaths = [[FSNodeRep sharedInstance] hiddenPaths];
-    int i, j;
+  if (self)
+    {
+      NSArray *hiddenPaths = [[FSNodeRep sharedInstance] hiddenPaths];
+      NSUInteger i, j;
 
-    fm = [NSFileManager defaultManager];
-    gw = [GWorkspace gworkspace];
+      fm = [NSFileManager defaultManager];
+      gw = [GWorkspace gworkspace];
 				        
-		makePosSel = @selector(makePositions);
-		makePos = (IMP)[self methodForSelector: makePosSel];
+      makePosSel = @selector(makePositions);
+      makePos = (IMP)[self methodForSelector: makePosSel];
 
-		gridPointSel = @selector(gridPointNearestToPoint:);
-		gridPoint = (GridPointIMP)[self methodForSelector: gridPointSel];
+      gridPointSel = @selector(gridPointNearestToPoint:);
+      gridPoint = (GridPointIMP)[self methodForSelector: gridPointSel];
 		
-    cellsWidth = CELLS_WIDTH;
+      cellsWidth = CELLS_WIDTH;
     		
-		watchedPaths = [[NSCountedSet alloc] initWithCapacity: 1];
+      watchedPaths = [[NSCountedSet alloc] initWithCapacity: 1];
 		    
-    focusedIconLabel = [NSTextField new];
-		[focusedIconLabel setFont: [NSFont systemFontOfSize: 12]];
-		[focusedIconLabel setBezeled: NO];
-		[focusedIconLabel setAlignment: NSCenterTextAlignment];
-    [focusedIconLabel setEditable: NO];
-    [focusedIconLabel setSelectable: NO];
-    [focusedIconLabel setBackgroundColor: [NSColor windowBackgroundColor]];
-	  [focusedIconLabel setTextColor: [NSColor controlTextColor]];
-    [focusedIconLabel setFrame: NSMakeRect(0, 0, 0, 14)];
+      focusedIconLabel = [NSTextField new];
+      [focusedIconLabel setFont: [NSFont systemFontOfSize: 12]];
+      [focusedIconLabel setBezeled: NO];
+      [focusedIconLabel setAlignment: NSCenterTextAlignment];
+      [focusedIconLabel setEditable: NO];
+      [focusedIconLabel setSelectable: NO];
+      [focusedIconLabel setBackgroundColor: [NSColor windowBackgroundColor]];
+      [focusedIconLabel setTextColor: [NSColor controlTextColor]];
+      [focusedIconLabel setFrame: NSMakeRect(0, 0, 0, 14)];
     
-    focusedIcon = nil;
+      focusedIcon = nil;
     
-		icons = [[NSMutableArray alloc] initWithCapacity: 1];
+      icons = [[NSMutableArray alloc] initWithCapacity: 1];
         
-    iconsType = itype;
-    isLastView = last;
+      iconsType = itype;
+      isLastView = last;
         
-    if (idescr && [idescr count]) {    
-      for (i = 0; i < [idescr count]; i++) { 
-			  NSDictionary *iconDict = [idescr objectAtIndex: i];
-			  int index = [[iconDict objectForKey: @"index"] intValue];
-        
-        if (iconsType == FILES_TAB) {
-          NSArray *iconpaths = [iconDict objectForKey: @"paths"];
-          BOOL canadd = YES;
+      if (idescr && [idescr count])
+	{
+	  for (i = 0; i < [idescr count]; i++)
+	    { 
+	      NSDictionary *iconDict = [idescr objectAtIndex: i];
+	      NSUInteger index = [[iconDict objectForKey: @"index"] unsignedIntValue];
+	      
+	      if (iconsType == FILES_TAB)
+		{
+		  NSArray *iconpaths = [iconDict objectForKey: @"paths"];
+		  BOOL canadd = YES;
 
-          for (j = 0; j < [iconpaths count]; j++) {
-            NSString *p = [iconpaths objectAtIndex: j];
-            if (([fm fileExistsAtPath: p] == NO) || [hiddenPaths containsObject: p]) {
-              canadd = NO;
-              break;
-            } 
-          }
-
-          if ((canadd == YES) && (index != -1)) {
-				    [self addIconWithPaths: iconpaths withGridIndex: index];
-          }
-          
-        } else {
-          NSString *dataPath = [iconDict objectForKey: @"datapath"];
-          NSString *dataType = [iconDict objectForKey: @"datatype"];
-                    
-          if ([fm fileExistsAtPath: dataPath]) {
-            [self addPBIconForDataAtPath: dataPath
-                                dataType: dataType
-					                 withGridIndex: index];
-          }
-        }
-      }
+		  for (j = 0; j < [iconpaths count]; j++)
+		    {
+		      NSString *p = [iconpaths objectAtIndex: j];
+		      if (([fm fileExistsAtPath: p] == NO) || [hiddenPaths containsObject: p])
+			{
+			  canadd = NO;
+			  break;
+			} 
+		    }
+		  
+		  if (canadd == YES)
+		    {
+		      [self addIconWithPaths: iconpaths withGridIndex: index];
+		    }
+		  
 		}
-        
-		gpoints = NULL;
-		pcount = 0;
-		isDragTarget = NO;
-		dragImage = nil;
-		
-    if (isLastView == NO) {
-      if (iconsType == FILES_TAB) {
-  	    [self registerForDraggedTypes: [NSArray arrayWithObjects: NSFilenamesPboardType, nil]];
-    
-		    [[NSNotificationCenter defaultCenter] 
+	      else
+		{
+		  NSString *dataPath = [iconDict objectForKey: @"datapath"];
+		  NSString *dataType = [iconDict objectForKey: @"datatype"];
+		  
+		  if ([fm fileExistsAtPath: dataPath])
+		    {
+		      [self addPBIconForDataAtPath: dataPath
+					  dataType: dataType
+				     withGridIndex: index];
+		    }
+		}
+	    }
+	}
+      
+      gpoints = NULL;
+      pcount = 0;
+      isDragTarget = NO;
+      dragImage = nil;
+	
+      if (isLastView == NO)
+	{
+	  if (iconsType == FILES_TAB)
+	    {
+	      [self registerForDraggedTypes: [NSArray arrayWithObjects: NSFilenamesPboardType, nil]];
+	      
+	      [[NSNotificationCenter defaultCenter] 
                    addObserver: self 
-                	    selector: @selector(fileSystemWillChange:) 
-                			    name: @"GWFileSystemWillChangeNotification"
-                		    object: nil];
+		      selector: @selector(fileSystemWillChange:) 
+			  name: @"GWFileSystemWillChangeNotification"
+			object: nil];
 
-		    [[NSNotificationCenter defaultCenter] 
+	      [[NSNotificationCenter defaultCenter] 
                    addObserver: self 
-                	    selector: @selector(fileSystemDidChange:) 
-                			    name: @"GWFileSystemDidChangeNotification"
-                		    object: nil];                     
-      } else {
-        NSArray *types = [NSArray arrayWithObjects: NSStringPboardType,
-                                                    NSRTFPboardType,
-                                                    NSRTFDPboardType,
-                                                    NSTIFFPboardType,
-                                                    NSFileContentsPboardType,
-                                                    NSColorPboardType,
-                                                    @"IBViewPboardType",
-                                                    nil];
-  	    [self registerForDraggedTypes: types];
-        [self setWatcherForPath: [gw tshelfPBDir]];
-      }
+		      selector: @selector(fileSystemDidChange:) 
+			  name: @"GWFileSystemDidChangeNotification"
+			object: nil];                     
+	    } 
+	  else 
+	    {
+	      NSArray *types = [NSArray arrayWithObjects: NSStringPboardType,
+					NSRTFPboardType,
+					NSRTFDPboardType,
+					NSTIFFPboardType,
+					NSFileContentsPboardType,
+					NSColorPboardType,
+					@"IBViewPboardType",
+					nil];
+	      [self registerForDraggedTypes: types];
+	      [self setWatcherForPath: [gw tshelfPBDir]];
+	    }
     
-		  [[NSNotificationCenter defaultCenter] 
+	  [[NSNotificationCenter defaultCenter] 
                  addObserver: self 
                     selector: @selector(watcherNotification:) 
-                		    name: @"GWFileWatcherFileDidChangeNotification"
-                	    object: nil];
-	  }
-  }
+			name: @"GWFileWatcherFileDidChangeNotification"
+		      object: nil];
+	}
+    }
   
   return self;	
 }
@@ -219,83 +243,93 @@
 - (NSArray *)iconsDescription
 { 
   NSMutableArray *arr = [NSMutableArray arrayWithCapacity: 1]; 
-  int i;
+  NSUInteger i;
 	  
-	for (i = 0; i < [icons count]; i++) {
-		NSMutableDictionary *dict = [NSMutableDictionary dictionaryWithCapacity: 1];
-    id icon;
-    int index;
+  for (i = 0; i < [icons count]; i++)
+    {
+      NSMutableDictionary *dict = [NSMutableDictionary dictionaryWithCapacity: 1];
+      id icon;
+      NSUInteger index;
 
-    icon = [icons objectAtIndex: i];
-    index = [icon gridindex];
-    [dict setObject: [NSNumber numberWithInt: index] forKey: @"index"];
+      icon = [icons objectAtIndex: i];
+      index = [icon gridindex];
+      [dict setObject: [NSNumber numberWithInt: index] forKey: @"index"];
 		
-    if (iconsType == FILES_TAB) {
-		  [dict setObject: [icon paths] forKey: @"paths"];
-    } else {
-		  [dict setObject: [icon dataPath] forKey: @"datapath"];
-		  [dict setObject: [icon dataType] forKey: @"datatype"];      
-    }
+      if (iconsType == FILES_TAB)
+	{
+	  [dict setObject: [icon paths] forKey: @"paths"];
+	}
+      else
+	{
+	  [dict setObject: [icon dataPath] forKey: @"datapath"];
+	  [dict setObject: [icon dataType] forKey: @"datatype"];      
+	}
     
-    [arr addObject: dict];
-  }
+      [arr addObject: dict];
+    }
   
   return arr;
 }
 
 - (void)addIconWithPaths:(NSArray *)iconpaths 
-					 withGridIndex:(int)index 
+	   withGridIndex:(NSUInteger)index 
 {
-	TShelfIcon *icon = [[TShelfIcon alloc] initForPaths: iconpaths 
-															 gridIndex: index inIconsView: self];
-	NSString *watched = [[iconpaths objectAtIndex: 0] stringByDeletingLastPathComponent];	
-	
-	if (gpoints != NULL) {
-		if (index < pcount) {
-			gpoints[index].used = 1;
-		}
+  TShelfIcon *icon = [[TShelfIcon alloc] initForPaths: iconpaths 
+					    gridIndex: index inIconsView: self];
+  NSString *watched = [[iconpaths objectAtIndex: 0] stringByDeletingLastPathComponent];
+  
+  if (gpoints != NULL)
+    {
+      if (index < pcount)
+	{
+	  gpoints[index].used = 1;
 	}
-	
-	[icons addObject: icon];  
-	[self addSubview: icon];
-	[self addSubview: [icon myLabel]];		
-	RELEASE (icon);    
-	[self sortIcons];	
-	[self resizeWithOldSuperviewSize: [self frame].size];  
+    }
+
+  [icons addObject: icon];  
+  [self addSubview: icon];
+  [self addSubview: [icon myLabel]];		
+  RELEASE (icon);    
+  [self sortIcons];	
+  [self resizeWithOldSuperviewSize: [self frame].size];  
+  
+  if ([watchedPaths containsObject: watched] == NO)
+    [self setWatcherForPath: watched];
 
-	if ([watchedPaths containsObject: watched] == NO) {
-		[self setWatcherForPath: watched];
-	}
   [watchedPaths addObject: watched];
 }
 
 - (TShelfPBIcon *)addPBIconForDataAtPath:(NSString *)dpath 
                                 dataType:(NSString *)dtype
-					                 withGridIndex:(int)index 
+			   withGridIndex:(NSUInteger)index 
 {
   TShelfPBIcon *icon = [[TShelfPBIcon alloc] initForPBDataAtPath: dpath
-                            ofType: dtype gridIndex: index inIconsView: self];
+							  ofType: dtype
+						       gridIndex: index
+						     inIconsView: self];
               
-	if (gpoints != NULL) {
-		if (index < pcount) {
-			gpoints[index].used = 1;
-		}
-	}
+  if (gpoints != NULL)
+    {
+      if (index < pcount) {
+	gpoints[index].used = 1;
+      }
+    }
 
-	[icons addObject: icon];  
-	[self addSubview: icon];
-	RELEASE (icon);    
-	[self sortIcons];	
-	[self resizeWithOldSuperviewSize: [self frame].size]; 
+  [icons addObject: icon];  
+  [self addSubview: icon];
+  RELEASE (icon);    
+  [self sortIcons];	
+  [self resizeWithOldSuperviewSize: [self frame].size]; 
   
   return icon; 
 }
 
 - (void)removeIcon:(id)anIcon
 {
-  if (anIcon) {
-    id label = [anIcon myLabel];
-    int index = [anIcon gridindex];	
+  if (anIcon)
+    {
+      id label = [anIcon myLabel];
+      NSUInteger index = [anIcon gridindex];	
 
     if (iconsType == FILES_TAB) {
 	    NSString *watched = [[[anIcon paths] objectAtIndex: 0] stringByDeletingLastPathComponent];
@@ -330,30 +364,33 @@
 
 - (void)removePBIconsWithData:(NSData *)data ofType:(NSString *)type
 {
-  int count = [icons count];
-  int i;
-
-  for (i = count - 1; i >= 0; i--) {
-    TShelfPBIcon *icon = [icons objectAtIndex: i];
-
-    if ([[icon dataType] isEqual: type]) {
-      if ([[icon data] isEqual: data]) {
-        NSString *dataPath = [icon dataPath];
+  NSUInteger count = [icons count];
+  NSUInteger i;
   
-        RETAIN (dataPath);
-        [self removeIcon: icon];
-        [fm removeFileAtPath: dataPath handler: nil];
-        RELEASE (dataPath);
-      }
+  for (i = 0; i < count; i++)
+    {
+      TShelfPBIcon *icon = [icons objectAtIndex: count-i];
+      
+      if ([[icon dataType] isEqual: type])
+	{
+	  if ([[icon data] isEqual: data])
+	    {
+	      NSString *dataPath = [icon dataPath];
+	      
+	      RETAIN (dataPath);
+	      [self removeIcon: icon];
+	      [fm removeFileAtPath: dataPath handler: nil];
+	      RELEASE (dataPath);
+	    }
+	}
     }
-  }
 }
 
 - (void)setLabelRectOfIcon:(id)anIcon
 {
   TShelfIcon *icon;
-	NSTextField *label;
-	float iconwidth, labwidth, labxpos;
+  NSTextField *label;
+  float iconwidth, labwidth, labxpos;
   NSRect labelRect;
   
   icon = (TShelfIcon *)anIcon;	
@@ -374,7 +411,7 @@
 
 - (BOOL)hasSelectedIcon
 {
-  int i;
+  NSUInteger i;
   
   for (i = 0; i < [icons count]; i++) {
     TShelfIcon *icon = [icons objectAtIndex: i];
@@ -388,7 +425,7 @@
 
 - (void)unselectOtherIcons:(id)anIcon
 {
-  int i;
+  NSUInteger i;
   
   for (i = 0; i < [icons count]; i++) {
     TShelfIcon *icon = [icons objectAtIndex: i];
@@ -469,7 +506,7 @@
 
 - (void)updateIcons
 {
-  int i;
+  NSUInteger i;
 
   for (i = 0; i < [icons count]; i++) {
     id icon = [icons objectAtIndex: i];
@@ -482,7 +519,7 @@
 
 - (id)selectedIcon
 {
-  int i;
+  NSUInteger i;
   
   for (i = 0; i < [icons count]; i++) {
     id icon = [icons objectAtIndex: i];
@@ -506,67 +543,78 @@
 
 - (void)checkIconsAfterDotsFilesChange
 {
-  if (iconsType == FILES_TAB) {
-    int count = [icons count]; 
-    int i;
+  if (iconsType == FILES_TAB)
+    {
+      NSUInteger count = [icons count]; 
+      NSUInteger i;
 
-	  for (i = 0; i < count; i++) {
-		  TShelfIcon *icon = [icons objectAtIndex: i];
-      NSArray *iconpaths = [icon paths];
-      int j;
+      for (i = 0; i < count; i++)
+	{
+	  TShelfIcon *icon = [icons objectAtIndex: i];
+	  NSArray *iconpaths = [icon paths];
+	  NSUInteger j;
 
-	    for (j = 0; j < [iconpaths count]; j++) {
-        NSString *op = [iconpaths objectAtIndex: j];
-
-        if ([op rangeOfString: @"."].location != NSNotFound) {
-          [self removeIcon: icon];
-          count--;
-          i--;
-          break;
-        }
-      }
-	  }
-  }
+	  for (j = 0; j < [iconpaths count]; j++)
+	    {
+	      NSString *op = [iconpaths objectAtIndex: j];
+	      
+	      if ([op rangeOfString: @"."].location != NSNotFound)
+		{
+		  [self removeIcon: icon];
+		  count--;
+		  i--;
+		  break;
+		}
+	    }
+	}
+    }
 }
 
 - (void)checkIconsAfterHidingOfPaths:(NSArray *)hpaths
 {
-  if (iconsType == FILES_TAB) {
-    int count = [icons count]; 
-    int i;
+  if (iconsType == FILES_TAB)
+    {
+      NSUInteger count = [icons count]; 
+      NSUInteger i;
 
-	  for (i = 0; i < count; i++) {
-      BOOL deleted = NO;
-		  TShelfIcon *icon = [icons objectAtIndex: i];
-      NSArray *iconpaths = [icon paths];
-      int j;
+      for (i = 0; i < count; i++)
+	{
+	  BOOL deleted = NO;
+	  TShelfIcon *icon = [icons objectAtIndex: i];
+	  NSArray *iconpaths = [icon paths];
+	  NSUInteger j;
+	  
+	  for (j = 0; j < [iconpaths count]; j++)
+	    {
+	      NSString *op = [iconpaths objectAtIndex: j];
+	      NSUInteger m;
+	      
+	      for (m = 0; m < [hpaths count]; m++)
+		{
+		  NSString *fp = [hpaths objectAtIndex: m]; 
+		  
+		  if (isSubpathOfPath(fp, op) || [fp isEqual: op])
+		    {  
+		      [self removeIcon: icon];
+		      count--;
+		      i--;
+		      deleted = YES;
+		      break;
+		    }
 
-	    for (j = 0; j < [iconpaths count]; j++) {
-        NSString *op = [iconpaths objectAtIndex: j];
-        int m;
-
-	      for (m = 0; m < [hpaths count]; m++) {
-          NSString *fp = [hpaths objectAtIndex: m]; 
-
-          if (isSubpathOfPath(fp, op) || [fp isEqual: op]) {  
-            [self removeIcon: icon];
-            count--;
-            i--;
-            deleted = YES;
-            break;
-          }
-
-          if (deleted) {
-            break;
-          } 
-        }
-
-        if (deleted) {
-          break;
-        }       
-      }
-	  }
-  }
+		  if (deleted)
+		    {
+		      break;
+		    } 
+		}
+	      
+	      if (deleted)
+		{
+		  break;
+		}       
+	    }
+	}
+    }
 }
 
 - (void)fileSystemWillChange:(NSNotification *)notification
@@ -574,8 +622,8 @@
   CREATE_AUTORELEASE_POOL(arp);
   NSDictionary *dict = [notification object];
   NSString *operation = [dict objectForKey: @"operation"];
-	NSString *source = [dict objectForKey: @"source"];	  
-	NSArray *files = [dict objectForKey: @"files"];	 
+  NSString *source = [dict objectForKey: @"source"];	  
+  NSArray *files = [dict objectForKey: @"files"];	 
 
   if ([operation isEqual: NSWorkspaceMoveOperation] 
         || [operation isEqual: NSWorkspaceDestroyOperation]
@@ -585,7 +633,7 @@
 				|| [operation isEqual: @"GWorkspaceEmptyRecyclerOperation"]) {
     NSMutableArray *paths = [NSMutableArray array];
     NSArray *iconpaths;
-    int i, j, m;
+    NSUInteger i, j, m;
 
     for (i = 0; i < [files count]; i++) {
       NSString *s = [source stringByAppendingPathComponent: [files objectAtIndex: i]];
@@ -637,8 +685,8 @@
     NSMutableArray *paths = [NSMutableArray arrayWithCapacity: 1];
     TShelfIcon *icon;
     NSArray *iconpaths;
-    int count;
-	  int i, j, m;
+    NSUInteger count;
+    NSUInteger i, j, m;
 
     for (i = 0; i < [files count]; i++) {
       NSString *s = [source stringByAppendingPathComponent: [files objectAtIndex: i]];
@@ -689,10 +737,10 @@
 	NSEnumerator *enumerator;
   NSString *wpath;
   BOOL contained = NO;
-	int i;
+  NSUInteger i;
   
   if (iconsType == DATA_TAB) {
-    int count = [icons count];
+    NSUInteger count = [icons count];
     
     if ([event isEqual: @"GWFileDeletedInWatchedDirectory"]) { 
       NSArray *files = [notifdict objectForKey: @"files"];
@@ -700,7 +748,7 @@
       for (i = 0; i < count; i++) {
         TShelfPBIcon *icon = [icons objectAtIndex: i];
         NSString *dataPath = [icon dataPath];
-        int j;
+        NSUInteger j;
 				  
         for (j = 0; j < [files count]; j++) {
           NSString *fname = [files objectAtIndex: j];
@@ -733,7 +781,7 @@
 		  id icon;
 		  NSArray *ipaths;
 		  NSString *ipath;
-		  int count = [icons count];
+		  NSUInteger count = [icons count];
 
 		  if ([event isEqual: @"GWWatchedPathDeleted"]) {		
 			  for (i = 0; i < count; i++) {
@@ -756,7 +804,7 @@
 			  NSArray *files = [notifdict objectForKey: @"files"];
 
 			  for (i = 0; i < count; i++) {
-				  int j;
+				  NSUInteger j;
 
 				  icon = [icons objectAtIndex: i];
 				  ipaths = [icon paths];				
@@ -782,7 +830,7 @@
 						  NSString *fname = [files objectAtIndex: j];
 						  NSString *fullPath = [path stringByAppendingPathComponent: fname];
 						  BOOL deleted = NO;
-						  int m;
+						  NSUInteger m;
 
 						  if (deleted) {
 							  break;
@@ -860,15 +908,15 @@
 
 - (void)makePositions
 {
-  float wdt, hgt, x, y;
-	int i;
+  CGFloat wdt, hgt, x, y;
+  NSUInteger i;
   
   wdt = [self bounds].size.width;
   hgt = [self bounds].size.height;
 	
-	pcount = (int)((wdt - 16) / cellsWidth);
+  pcount = (NSUInteger)((wdt - 16) / cellsWidth);
 		
- 	if (gpoints != NULL) {
+  if (gpoints != NULL) {
 		NSZoneFree (NSDefaultMallocZone(), gpoints);
 	} 
 	gpoints = NSZoneMalloc (NSDefaultMallocZone(), sizeof(gridpoint) * pcount);		
@@ -895,14 +943,14 @@
 - (gridpoint *)gridPointNearestToPoint:(NSPoint)p
 {
   NSRect r = [self bounds];
-	float maxx = r.size.width;
-	float maxy = r.size.height;
+	CGFloat maxx = r.size.width;
+	CGFloat maxy = r.size.height;
 	float px = p.x;
 	float py = p.y;	
 	float minx = maxx;
 	float miny = maxy;
 	int pos = -1;
-	int i;
+	NSUInteger i;
 		
 	for (i = 0; i < pcount; i++) {
 		if (gpoints[i].y > 0) {
@@ -922,16 +970,17 @@
 
 - (BOOL)isFreePosition:(NSPoint)pos
 {
-	int i;
-	
-	for (i = 0; i < [icons count]; i++) {
-		NSPoint p = [[icons objectAtIndex: i] position];
-		if (NSEqualPoints(pos, p)) {
-			return NO;
-		}
-  }
-
-	return YES;
+  NSUInteger i;
+  
+  for (i = 0; i < [icons count]; i++)
+    {
+      NSPoint p = [[icons objectAtIndex: i] position];
+      if (NSEqualPoints(pos, p)) {
+        return NO;
+      }
+    }
+  
+  return YES;
 }
 
 - (int)cellsWidth
@@ -947,35 +996,39 @@
 
 - (void)resizeWithOldSuperviewSize:(NSSize)oldFrameSize
 {
-	int i;
+  NSUInteger i;
 				
-	if (gpoints == NULL) {
-		[super resizeWithOldSuperviewSize: oldFrameSize];
-		return;
-	}
+  if (gpoints == NULL)
+    {
+      [super resizeWithOldSuperviewSize: oldFrameSize];
+      return;
+    }
 		
-	for (i = 0; i < pcount; i++) {	
-		gpoints[i].used = 0;
-	}
-	
-	for (i = 0; i < [icons count]; i++) {	
-		id icon	 = [icons objectAtIndex: i];
-		int index = [icon gridindex];		
-		gridpoint gpoint = gpoints[index];
-		NSPoint p = NSMakePoint(gpoint.x, gpoint.y);
-		NSRect r = NSMakeRect(p.x, p.y, 64, 52);
-
-		[icon setPosition: p];
-		[icon setFrame: NSIntegralRect(r)];
-		gpoints[index].used = 1;
-    
-    if (iconsType == FILES_TAB) {
-		  [self setLabelRectOfIcon: icon];		
+  for (i = 0; i < pcount; i++)
+    {	
+      gpoints[i].used = 0;
     }
-	}
 	
-	[self sortIcons];
-	[self setNeedsDisplay: YES];
+  for (i = 0; i < [icons count]; i++)
+    {	
+      id icon	 = [icons objectAtIndex: i];
+      NSUInteger index = [icon gridindex];		
+      gridpoint gpoint = gpoints[index];
+      NSPoint p = NSMakePoint(gpoint.x, gpoint.y);
+      NSRect r = NSMakeRect(p.x, p.y, 64, 52);
+      
+      [icon setPosition: p];
+      [icon setFrame: NSIntegralRect(r)];
+      gpoints[index].used = 1;
+      
+      if (iconsType == FILES_TAB)
+        {
+          [self setLabelRectOfIcon: icon];		
+        }
+    }
+	
+  [self sortIcons];
+  [self setNeedsDisplay: YES];
 }
 
 - (void)mouseDown:(NSEvent *)theEvent
@@ -1075,17 +1128,17 @@
      
   if (data && [[TShelfPBIcon dataTypes] containsObject: type]) {         
     NSString *dpath = [gw tshelfPBFilePath];
-		int index = -1; 
-    int i;
+    NSUInteger index = NSNotFound; 
+    NSUInteger i;
     
-	  for (i = 0; i < pcount; i++) {
-		  if (gpoints[i].used == 0) {
+    for (i = 0; i < pcount; i++) {
+      if (gpoints[i].used == 0) {
         index = i;
-		    break;
+        break;
       }
     }
     
-    if (index == -1) {
+    if (index == NSNotFound) {
       NSRunAlertPanel(NSLocalizedString(@"Error!", @""),
                         NSLocalizedString(@"No space left on this tab", @""),
                         NSLocalizedString(@"Ok", @""),
@@ -1108,7 +1161,7 @@
   NSArray *types = [pboard types];
   NSData *data;
   NSString *type;
-  int i;
+  NSUInteger i;
   
   if ((types == nil) || ([types count] == 0)) {
     return nil;
@@ -1139,12 +1192,13 @@
   
   DESTROY (dragImage);
   
-  if (iconsType == FILES_TAB) {
-	  if ((sourceDragMask == NSDragOperationCopy) 
-												  || (sourceDragMask == NSDragOperationLink)) {
-		  return NSDragOperationNone;
-	  }
-  }
+  if (iconsType == FILES_TAB)
+    {
+      if ((sourceDragMask == NSDragOperationCopy) || (sourceDragMask == NSDragOperationLink))
+        {
+          return NSDragOperationNone;
+        }
+    }
   
   if (iconsType == FILES_TAB) {  
     if ([[pb types] indexOfObject: NSFilenamesPboardType] != NSNotFound) {
@@ -1184,7 +1238,7 @@
 		DESTROY (dragImage);
 		dragPoint = [sender draggedImageLocation];	
 		dragPoint = [self convertPoint: dragPoint 
-													fromView: [[self window] contentView]];													
+                                      fromView: [[self window] contentView]];	
 		gpoint = [self gridPointNearestToPoint: dragPoint];						
 		dragPoint = NSMakePoint(gpoint->x, gpoint->y);
     ASSIGN (dragImage, [sender draggedImage]);
@@ -1192,7 +1246,7 @@
 		[self setNeedsDisplay: YES];
     
     if (iconsType == FILES_TAB) { 
-      return NSDragOperationAll;
+      return NSDragOperationEvery;
     } else {
       return NSDragOperationCopy;
     }
@@ -1247,7 +1301,7 @@
 	}
   
   if (iconsType == FILES_TAB) { 
-    return NSDragOperationAll;
+    return NSDragOperationEvery;
   } else {
     return NSDragOperationCopy;
   }
@@ -1278,62 +1332,72 @@
   NSPasteboard *pb = [sender draggingPasteboard];
   NSPoint p = [sender draggedImageLocation];
   gridpoint *gpoint;
-  int index;
-  int i;
+  NSUInteger index;
+  NSUInteger i;
 
   isDragTarget = NO;
 
-  if (dragImage != nil) {
-    DESTROY (dragImage);
-    [self setNeedsDisplay: YES];
-  }
-
+  if (dragImage != nil)
+    {
+      DESTROY (dragImage);
+      [self setNeedsDisplay: YES];
+    }
+  
   p = [self convertPoint: p fromView: [[self window] contentView]];
   gpoint = [self gridPointNearestToPoint: p];
   p = NSMakePoint(gpoint->x, gpoint->y);
   index = gpoint->index;
 
-  if (gpoint->used == 0) {
-    if (iconsType == FILES_TAB) {
-      NSArray *sourcePaths = [pb propertyListForType: NSFilenamesPboardType]; 
-      sourcePaths = [pb propertyListForType: NSFilenamesPboardType];
-
-	    if (sourcePaths) {
-    	  for (i = 0; i < [icons count]; i++) {
-      	  TShelfIcon *icon = [icons objectAtIndex: i];
-      	  if ([[icon paths] isEqualToArray: sourcePaths]) {
-					  gpoints[[icon gridindex]].used = 0;
-					  gpoint->used = 1;					  
-					  [icon setGridIndex: index];
-        	  [self resizeWithOldSuperviewSize: [self frame].size];
-        	  return;
-      	  }
-    	  }
-
-			  [self addIconWithPaths: sourcePaths withGridIndex: index];
-	    }
-    } else {
-      NSData *data;
-      NSString *type;
-      
-      data = [self readSelectionFromPasteboard: pb ofType: &type];
-
-      if (data) {   
-        NSString *dpath = [gw tshelfPBFilePath];
-        
-        if ([data writeToFile: dpath atomically: YES]) {
-          TShelfPBIcon *icon;
-          
-          [self removePBIconsWithData: data ofType: type];
-        
-          icon = [self addPBIconForDataAtPath: dpath
-                                     dataType: type
-					                      withGridIndex: index];
-          [icon select];                      
+  if (gpoint->used == 0)
+    {
+      if (iconsType == FILES_TAB)
+        {
+          NSArray *sourcePaths; 
+          sourcePaths = [pb propertyListForType: NSFilenamesPboardType];
+            
+          if (sourcePaths)
+            {
+              for (i = 0; i < [icons count]; i++)
+                {
+                  TShelfIcon *icon = [icons objectAtIndex: i];
+                  if ([[icon paths] isEqualToArray: sourcePaths])
+                    {
+                      gpoints[[icon gridindex]].used = 0;
+                      gpoint->used = 1;					  
+                      [icon setGridIndex: index];
+                      [self resizeWithOldSuperviewSize: [self frame].size];        	  
+                      return;
+                    }
+                }
+                
+              [self addIconWithPaths: sourcePaths withGridIndex: index];
+            }
         }
-      }
-    }  
-  }
+      else
+        {
+          NSData *data;
+          NSString *type;
+      
+          data = [self readSelectionFromPasteboard: pb ofType: &type];
+
+          if (data)
+            {   
+              NSString *dpath = [gw tshelfPBFilePath];
+        
+              if ([data writeToFile: dpath atomically: YES])
+                {
+                  TShelfPBIcon *icon;
+          
+                  [self removePBIconsWithData: data ofType: type];
+        
+                  icon = [self addPBIconForDataAtPath: dpath
+                                             dataType: type
+                                        withGridIndex: index];
+                  [icon select];                      
+                }
+            }
+        }  
+    }
 }
 
 @end
