@@ -1,6 +1,6 @@
 /* SoundViewer.m
  *  
- * Copyright (C) 2004 Free Software Foundation, Inc.
+ * Copyright (C) 2004-2011 Free Software Foundation, Inc.
  *
  * Author: Enrico Sersale <enrico@imago.ro>
  * Date: January 2004
@@ -22,18 +22,18 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111 USA.
  */
 
-#include <AppKit/AppKit.h>
-#include "SoundViewer.h"
+#import <AppKit/AppKit.h>
+#import "SoundViewer.h"
 
 @implementation SoundViewer
 
 - (void)dealloc
 {
-	TEST_RELEASE (soundPath);
-	TEST_RELEASE (sound);
+  TEST_RELEASE (soundPath);
+  TEST_RELEASE (sound);
   RELEASE (playBox);  
   RELEASE (errLabel);
-	RELEASE (indicator);
+  RELEASE (indicator);
   [super dealloc];
 }
 
@@ -189,44 +189,52 @@
 {
   NSSound *snd;
   
-	if (sound) {
-		if ([sound isPlaying]) {
-			[sound stop];
-			[indicator stopAnimation: self];
-		}
-		DESTROY (sound);
+  if (sound)
+    {
+      if ([sound isPlaying]) 
+	{
+	  [sound stop];
+	  [indicator stopAnimation: self];
 	}
+      DESTROY (sound);
+    }
   
-	ASSIGN (soundPath, path);
+  ASSIGN (soundPath, path);
 
-  if ([self superview]) {      
-    [inspector contentsReadyAt: soundPath];
-  }
+  if ([self superview]) 
+    {      
+      [inspector contentsReadyAt: soundPath];
+    }
   
   snd = [[NSSound alloc] initWithContentsOfFile: soundPath 
                                     byReference: NO]; 
   
-  if (snd) {
-    ASSIGN (sound, snd);
-  
-		if (valid == NO) {
-			[errLabel removeFromSuperview]; 
-      [self addSubview: playBox];   
-			valid = YES;
-		}		  
+  if (snd)
+    {
+      ASSIGN (sound, snd);
+      [sound setDelegate: self];
+      if (valid == NO) 
+	{
+	  [errLabel removeFromSuperview]; 
+	  [self addSubview: playBox];   
+	  valid = YES;
+	}		  
     
-    [editButt setEnabled: YES];	
-    [[self window] makeFirstResponder: editButt];
+      [editButt setEnabled: YES];	
+      [[self window] makeFirstResponder: editButt];
     	
-  } else {
-    if (valid == YES) {
-      DESTROY (sound);
-			[playBox removeFromSuperview]; 
-      [self addSubview: errLabel]; 
-      [editButt setEnabled: NO];		      
-			valid = NO;
+    } 
+  else 
+    {
+      if (valid == YES) 
+	{
+	  DESTROY (sound);
+	  [playBox removeFromSuperview]; 
+	  [self addSubview: errLabel]; 
+	  [editButt setEnabled: NO];		      
+	  valid = NO;
+	}
     }
-  }
   
   DESTROY (snd);
 }
@@ -288,9 +296,9 @@
 	if ([types containsObject: [extension lowercaseString]]) {
 		return YES;
 	}
-//	if ([[NSSound soundUnfilteredFileTypes] containsObject: extension]) {
-//		return YES;
-//	}
+	if ([[NSSound soundUnfilteredFileTypes] containsObject: extension]) {
+		return YES;
+	}
 
 	return NO;
 }
@@ -336,4 +344,9 @@
   }
 }
 
+- (void) sound:(NSSound *)sound didFinishPlaying:(BOOL)aBool
+{
+  [indicator stopAnimation: self];
+}
+
 @end
