@@ -1,6 +1,6 @@
 /* FileOpInfo.m
  *  
- * Copyright (C) 2004-2010 Free Software Foundation, Inc.
+ * Copyright (C) 2004-2013 Free Software Foundation, Inc.
  *
  * Author: Enrico Sersale <enrico@imago.ro>
  * Date: March 2004
@@ -784,53 +784,60 @@ static NSString *nibName = @"FileOperationWin";
 
 - (oneway void)calculateNumFiles
 {
-  int i, fnum = 0;
+  NSUInteger i;
+  NSUInteger fnum = 0;
 
-  for (i = 0; i < [files count]; i++) {
-    CREATE_AUTORELEASE_POOL (arp);
-    NSDictionary *dict = [files objectAtIndex: i];
-    NSString *name = [dict objectForKey: @"name"]; 
-    NSString *path = [source stringByAppendingPathComponent: name];       
-	  BOOL isDir = NO;
+  for (i = 0; i < [files count]; i++)
+    {
+      CREATE_AUTORELEASE_POOL (arp);
+      NSDictionary *dict = [files objectAtIndex: i];
+      NSString *name = [dict objectForKey: @"name"]; 
+      NSString *path = [source stringByAppendingPathComponent: name];       
+      BOOL isDir = NO;
     
-	  [fm fileExistsAtPath: path isDirectory: &isDir];
-    
-	  if (isDir) {
-      NSDirectoryEnumerator *enumerator = [fm enumeratorAtPath: path];
+      [fm fileExistsAtPath: path isDirectory: &isDir];
       
-      while (1) {
-        CREATE_AUTORELEASE_POOL (arp2);
-        NSString *dirEntry = [enumerator nextObject];
-      
-        if (dirEntry) {
-          if (stopped) {
-            break;
-          }
-			    fnum++;
-        
-        } else {
-          RELEASE (arp2);
-          break;
+      if (isDir)
+        {
+          NSDirectoryEnumerator *enumerator = [fm enumeratorAtPath: path];
+          
+          while (1)
+            {
+              CREATE_AUTORELEASE_POOL (arp2);
+              NSString *dirEntry = [enumerator nextObject];
+              
+              if (dirEntry)
+                {
+                  if (stopped)
+                    {
+                      RELEASE (arp2);
+                      break;
+                    }
+                  fnum++;
+                }
+              else
+                {
+                  RELEASE (arp2);
+                  break;
+                }
+              RELEASE (arp2);
+            }
+        }
+      else
+        {
+          fnum++;
         }
       
-        RELEASE (arp2);
-      }
-            
-	  } else {
-		  fnum++;
-	  }
-    
-    if (stopped) {
+      if (stopped)
+        {
+          RELEASE (arp);
+          break;
+        }
       RELEASE (arp);
-      break;
     }
-    
-    RELEASE (arp);
-  }
 
-  if (stopped) {
+  if (stopped)
     [self done];
-  }
 
   fcount = 0;
   stepcount = 0;
@@ -1106,10 +1113,11 @@ filename = [fileinfo objectForKey: @"name"];
   NSString *newname;
   NSString *ntmp;
 
-  while (1) {
-	  CHECK_DONE;      
-	  GET_FILENAME;  
-
+  while (1)
+    {
+      CHECK_DONE;      
+      GET_FILENAME;  
+      
     newname = [NSString stringWithString: filename];
     srcpath = [source stringByAppendingPathComponent: filename];
     destpath = [destination stringByAppendingPathComponent: newname];
@@ -1117,9 +1125,7 @@ filename = [fileinfo objectForKey: @"name"];
     if ([fm fileExistsAtPath: destpath]) {
       NSString *ext = [filename pathExtension]; 
       NSString *base = [filename stringByDeletingPathExtension]; 
-      int count = 1;
-      
-      newname = [NSString stringWithString: filename];
+      NSUInteger count = 1;
       
 	    while (1) {
         if (count == 1) {
@@ -1279,7 +1285,7 @@ filename = [fileinfo objectForKey: @"name"];
       if (found) {
         [self performOperation]; 
       } else {
-        result = [fileOp showErrorAlertWithMessage: @"File Operation Error!"];
+        [fileOp showErrorAlertWithMessage: @"File Operation Error!"];
         [self done];
       }
     } else {
@@ -1287,7 +1293,7 @@ filename = [fileinfo objectForKey: @"name"];
     }
   }
   
-	return YES;
+  return YES;
 }
 
 - (void)fileManager:(NSFileManager *)manager willProcessPath:(NSString *)path
