@@ -1,6 +1,6 @@
 /* DDBPathsManager.m
  *  
- * Copyright (C) 2005-2011 Free Software Foundation, Inc.
+ * Copyright (C) 2005-2013 Free Software Foundation, Inc.
  *
  * Author: Enrico Sersale <enrico@imago.ro>
  * Date: July 2005
@@ -55,7 +55,7 @@
     NSBundle *bundle;
     NSString *bundlesDir;
     NSArray *bnames;
-    unsigned i;
+    NSUInteger i;
 
     ulen = sizeof(unsigned);
     llen = sizeof(unsigned long);
@@ -131,7 +131,7 @@
   DDBPath *ddbpath = nil;
   DBKBTreeNode *node;
   BOOL exists;
-  int index;
+  NSUInteger index;
 
   DESTROY (dummyPaths[1]);  
   DESTROY (dummyPaths[0]);  
@@ -200,7 +200,7 @@
 {
   CREATE_AUTORELEASE_POOL(arp);
   DBKBTreeNode *node; 
-  int index;
+  NSUInteger index;
   BOOL exists;
 
   DESTROY (dummyPaths[1]);
@@ -289,9 +289,10 @@
 
 - (NSArray *)metadataForPath:(NSString *)apath
 {
+  CREATE_AUTORELEASE_POOL(arp);
   NSMutableArray *alldata = [NSMutableArray array];
   NSArray *types = [mdmodules allKeys];
-  int i;
+  NSUInteger i;
 
   for (i = 0; i < [types count]; i++) {
     NSString *type = [types objectAtIndex: i];
@@ -306,8 +307,9 @@
       [alldata addObject: dict];
     }
   }
-  
-  return alldata;
+  [alldata retain];
+  RELEASE (arp);
+  return [alldata autorelease];
 }
 
 - (NSTimeInterval)timestampOfPath:(NSString *)path
@@ -325,9 +327,8 @@
 {
   CREATE_AUTORELEASE_POOL(arp);
   DBKBTreeNode *node; 
-  int index;
-  BOOL exists;
-  
+  NSUInteger index;
+  BOOL exists;  
   DESTROY (dummyPaths[1]);
   ASSIGN (dummyPaths[0], ddbpath);  
 
@@ -354,7 +355,7 @@
                     forPath:(NSString *)dstpath
 {
   NSArray *types = [mdmodules allKeys];
-  int i;
+  NSUInteger i;
 
   for (i = 0; i < [types count]; i++) {
     NSString *type = [types objectAtIndex: i];
@@ -373,7 +374,7 @@
 - (void)duplicateDataOfPaths:(NSArray *)srcpaths
                     forPaths:(NSArray *)dstpaths
 {
-  int i, j;
+  NSUInteger i, j;
 
   for (i = 0; i < [srcpaths count]; i++) {
     CREATE_AUTORELEASE_POOL(arp);
@@ -412,7 +413,7 @@
   NSMutableArray *toremove = [NSMutableArray array];
   NSArray *keys = nil;
   NSString *dmstr[2];
-  int i;
+  NSUInteger i;
 
   [tree begin];
     
@@ -421,7 +422,7 @@
     dmstr[1] = [path stringByAppendingString: @"0"];
   } else {
     dmstr[0] = path;
-    dmstr[1] = [NSString stringWithString: @"0"];
+    dmstr[1] = @"0";
   }
 
   dummyPaths[0] = [[DDBPath alloc] initForPath: dmstr[0]];
@@ -480,7 +481,7 @@
   NSRange range;
   unsigned kcount;
   unsigned long key;
-  int i;
+  NSUInteger i;
   
   range = NSMakeRange(0, sizeof(unsigned));
   [data getBytes: &kcount range: range];
@@ -503,7 +504,7 @@
 {
   NSMutableData *data = [NSMutableData dataWithCapacity: 1];
   unsigned kcount = [keys count];
-  int i;
+  NSUInteger i;
   
   [data appendData: [NSData dataWithBytes: &kcount length: sizeof(unsigned)]];
     
