@@ -1,6 +1,6 @@
 /* ddbd.m
  *  
- * Copyright (C) 2004-2010 Free Software Foundation, Inc.
+ * Copyright (C) 2004-2013 Free Software Foundation, Inc.
  *
  * Author: Enrico Sersale <enrico@imago.ro>
  * Date: February 2004
@@ -54,12 +54,12 @@ static BOOL	auto_stop = NO;		/* Should we shut down when unused? */
 
 - (void)dealloc
 {
-  if (conn) {
-    [nc removeObserver: self
-		              name: NSConnectionDidDieNotification
-		            object: conn];
-    DESTROY (conn);
-  }
+  if (conn)
+    {
+      [nc removeObserver: self
+                    name: NSConnectionDidDieNotification
+                  object: conn];
+    }
 
   RELEASE (dbdir);
             
@@ -203,7 +203,6 @@ static BOOL	auto_stop = NO;		/* Should we shut down when unused? */
 
 - (NSData *)directoryTreeFromPath:(NSString *)apath
 {  
-  CREATE_AUTORELEASE_POOL(pool);
   NSArray *directories;  
   NSData *data = nil;
   
@@ -214,31 +213,23 @@ static BOOL	auto_stop = NO;		/* Should we shut down when unused? */
   if ([directories count]) { 
     data = [NSArchiver archivedDataWithRootObject: directories]; 
   } 
-
-  RETAIN (data);
-  RELEASE (pool);
   
-  return AUTORELEASE (data);
+  return data;
 }
 
 - (NSArray *)userMetadataForPath:(NSString *)apath
 {
-  CREATE_AUTORELEASE_POOL(arp);
   NSArray *usrdata = nil;
   
   [pathslock lock];
   usrdata = [pathsManager metadataForPath: apath];
   [pathslock unlock];
 
-  RETAIN (usrdata);
-  RELEASE (arp);
-
   return usrdata;
 }
 
 - (NSString *)annotationsForPath:(NSString *)path
 {
-  CREATE_AUTORELEASE_POOL(arp);
   NSString *annotations = nil;
   
   [pathslock lock];
@@ -246,9 +237,6 @@ static BOOL	auto_stop = NO;		/* Should we shut down when unused? */
                                      forPath: path];
   [pathslock unlock];
 
-  RETAIN (annotations);
-  RELEASE (arp);
-
   return annotations;
 }
 
@@ -352,13 +340,13 @@ static BOOL	auto_stop = NO;		/* Should we shut down when unused? */
 - (void)dealloc
 {
   RELEASE (updinfo);
-	[super dealloc];
+  [super dealloc];
 }
 
 + (void)updaterForTask:(NSDictionary *)info
 {
   CREATE_AUTORELEASE_POOL(arp);
-  DBUpdater *updater = [[self alloc] init];
+  DBUpdater *updater = [[DBUpdater alloc] init];
   
   [updater setUpdaterTask: info];
 
@@ -372,8 +360,6 @@ static BOOL	auto_stop = NO;		/* Should we shut down when unused? */
   int type = [[info objectForKey: @"type"] intValue];
   
   ASSIGN (updinfo, dict);
-  
-  RETAIN (self);
     
   GWDebugLog(@"starting db update");
 
@@ -509,18 +495,17 @@ int main(int argc, char** argv)
   CREATE_AUTORELEASE_POOL(pool);
   NSProcessInfo *info = [NSProcessInfo processInfo];
   NSMutableArray *args = AUTORELEASE ([[info arguments] mutableCopy]);
-  static BOOL	is_daemon = NO;
   BOOL subtask = YES;
 
-  if ([[info arguments] containsObject: @"--auto"] == YES)
-  {
-    auto_stop = YES;
-  }
+  if ([args containsObject: @"--auto"] == YES)
+    {
+      auto_stop = YES;
+    }
 
-  if ([[info arguments] containsObject: @"--daemon"]) {
-    subtask = NO;
-    is_daemon = YES;
-  }
+  if ([args containsObject: @"--daemon"])
+    {
+      subtask = NO;
+    }
 
   if (subtask) {
     NSTask *task = [NSTask new];
