@@ -1,6 +1,6 @@
 /* fswatcher.m
  *  
- * Copyright (C) 2004-2011 Free Software Foundation, Inc.
+ * Copyright (C) 2004-2013 Free Software Foundation, Inc.
  *
  * Author: Enrico Sersale <enrico@imago.ro>
  * Date: February 2004
@@ -29,6 +29,7 @@
   do { if (GW_DEBUG_LOG) \
     NSLog(format , ## args); } while (0)
 
+static BOOL	is_daemon = NO;		/* Currently running as daemon.	 */
 static BOOL	auto_stop = NO;		/* Should we shut down when unused? */
 
 @implementation	FSWClientInfo
@@ -86,7 +87,7 @@ static BOOL	auto_stop = NO;		/* Should we shut down when unused? */
   [wpaths removeObject: path];
 }
 
-- (BOOL)isWathchingPath:(NSString *)path
+- (BOOL)isWatchingPath:(NSString *)path
 {
   return [wpaths containsObject: path];
 }
@@ -235,7 +236,6 @@ static BOOL	auto_stop = NO;		/* Should we shut down when unused? */
       {
         Watcher *watcher = [self watcherForPath: wpath];
       
-        NSLog(@"No next in enumerator");
         if (watcher)
 	{
           [watcher removeListener];
@@ -244,11 +244,13 @@ static BOOL	auto_stop = NO;		/* Should we shut down when unused? */
       
       [clientsInfo removeObject: info];
     }
-    if (auto_stop == YES && [clientsInfo count] == 1)
+
+    if (auto_stop == YES && [clientsInfo count] <= 1)
       {
 	/* If there is nothing else using this process, and this is not
 	 * a daemon, then we can quietly terminate.
 	 */
+        NSLog(@"No more clients, shutting down.");
         exit(EXIT_SUCCESS);
       }
   }
@@ -258,7 +260,7 @@ static BOOL	auto_stop = NO;		/* Should we shut down when unused? */
 {
   NSUserDefaults *defaults = [NSUserDefaults standardUserDefaults];
   id entry;
-  unsigned i;
+  NSUInteger i;
   
   [defaults synchronize];
 
@@ -325,7 +327,7 @@ static BOOL	auto_stop = NO;		/* Should we shut down when unused? */
   NSArray *excluded = [info objectForKey: @"GSMetadataExcludedPaths"];
   NSArray *suffixes = [info objectForKey: @"GSMetadataExcludedSuffixes"];
   
-  unsigned i;
+  NSUInteger i;
 
   emptyTreeWithBase(includePathsTree);
   
@@ -378,7 +380,7 @@ static BOOL	auto_stop = NO;		/* Should we shut down when unused? */
   NSEnumerator *enumerator;
   NSString *wpath;
 
-	if (info == nil) {
+  if (info == nil) {
     [NSException raise: NSInternalInconsistencyException
 		            format: @"unregistration with unknown connection"];
   }
@@ -404,8 +406,8 @@ static BOOL	auto_stop = NO;		/* Should we shut down when unused? */
 	            object: connection];
 
   [clientsInfo removeObject: info];
-  NSLog(@"unregister client %lu", [clientsInfo count]);
-  if (auto_stop == YES && [clientsInfo count] == 1)
+
+  if (auto_stop == YES && [clientsInfo count] <= 1)
     {
       /* If there is nothing else using this process, and this is not
        * a daemon, then we can quietly terminate.
@@ -551,30 +553,24 @@ static BOOL	auto_stop = NO;		/* Should we shut down when unused? */
 
 static inline BOOL isDotFile(NSString *path)
 {
-  int len = ([path length] - 1);
-  static unichar sep = 0;  
-  unichar c;
-  int i;
-  
-  if (sep == 0) {
-    #if defined(__MINGW32__)
-      sep = '\\';	
-    #else
-      sep = '/';	
-    #endif
-  }
-  
-  for (i = len; i >= 0; i--) {
-    c = [path characterAtIndex: i];
-    
-    if (c == '.') {
-      if ((i > 0) && ([path characterAtIndex: (i - 1)] == sep)) {
-        return YES;
-      }
+  NSArray *components;
+  NSEnumerator *e;
+  NSString *c;
+  BOOL found;
+
+  if (path == nil)
+    return NO;
+
+  found = NO;
+  components = [path pathComponents];
+  e = [components objectEnumerator];
+  while ((c = [e nextObject]) && !found)
+    {
+      if (([c length] > 0) && ([c characterAtIndex:0] == '.'))
+	found = YES;
     }
-  }
-  
-  return NO;  
+
+  return found;  
 }
 
 - (BOOL)isGlobalValidPath:(NSString *)path
@@ -593,75 +589,87 @@ static inline BOOL isDotFile(NSString *path)
   NSString *path = [info objectForKey: @"path"];
   NSString *event = [info objectForKey: @"event"];
   NSData *data = [NSArchiver archivedDataWithRootObject: info];
-  int i;
+  NSUInteger i;
 
-  for (i = 0; i < [clientsInfo count]; i++) {
-    FSWClientInfo *clinfo = [clientsInfo objectAtIndex: i];
+  for (i = 0; i < [clientsInfo count]; i++)
+    {
+      FSWClientInfo *clinfo = [clientsInfo objectAtIndex: i];
   
-		if ([clinfo isWathchingPath: path]) {
-			[[clinfo client] watchedPathDidChange: data];
-		}
-  }
+      if ([clinfo isWatchingPath: path])
+	{
+	  [[clinfo client] watchedPathDidChange: data];
+	}
+    }
   
   if ([event isEqual: @"GWWatchedPathDeleted"] 
-                                && [self isGlobalValidPath: path]) {
-    GWDebugLog(@"DELETE %@", path);
-    [self notifyGlobalWatchingClients: info];
+      && [self isGlobalValidPath: path])
+    {
+      GWDebugLog(@"DELETE %@", path);
+      [self notifyGlobalWatchingClients: info];
     
-  } else if ([event isEqual: @"GWWatchedFileModified"] 
-                                      && [self isGlobalValidPath: path]) {
-    GWDebugLog(@"MODIFIED %@", path);
-    [self notifyGlobalWatchingClients: info];    
+    }
+  else if ([event isEqual: @"GWWatchedFileModified"] 
+	   && [self isGlobalValidPath: path])
+    {
+      GWDebugLog(@"MODIFIED %@", path);
+      [self notifyGlobalWatchingClients: info];    
     
-  } else if ([event isEqual: @"GWFileDeletedInWatchedDirectory"]) {
-    NSArray *files = [info objectForKey: @"files"];
+    } 
+  else if ([event isEqual: @"GWFileDeletedInWatchedDirectory"])
+    {
+      NSArray *files = [info objectForKey: @"files"];
     
-    for (i = 0; i < [files count]; i++) {
-      NSString *fname = [files objectAtIndex: i];
-      NSString *fullpath = [path stringByAppendingPathComponent: fname];
+      for (i = 0; i < [files count]; i++)
+	{
+	  NSString *fname = [files objectAtIndex: i];
+	  NSString *fullpath = [path stringByAppendingPathComponent: fname];
       
-      if ([self isGlobalValidPath: fullpath]) {
-        NSMutableDictionary *dict = [NSMutableDictionary dictionary];
-        
-        [dict setObject: fullpath forKey: @"path"];
-        [dict setObject: @"GWWatchedPathDeleted" forKey: @"event"];
+	  if ([self isGlobalValidPath: fullpath])
+	    {
+	      NSMutableDictionary *dict = [NSMutableDictionary dictionary];
+	      
+	      [dict setObject: fullpath forKey: @"path"];
+	      [dict setObject: @"GWWatchedPathDeleted" forKey: @"event"];
       
-        [self notifyGlobalWatchingClients: dict];
-      }      
-    }  
+	      [self notifyGlobalWatchingClients: dict];
+	    }      
+	}  
   
-  } else if ([event isEqual: @"GWFileCreatedInWatchedDirectory"]) {
-    NSArray *files = [info objectForKey: @"files"];
-    
-    for (i = 0; i < [files count]; i++) {
-      NSString *fname = [files objectAtIndex: i];
-      NSString *fullpath = [path stringByAppendingPathComponent: fname];
-      
-      if ([self isGlobalValidPath: fullpath]) {
-        NSMutableDictionary *dict = [NSMutableDictionary dictionary];
-        
-        [dict setObject: fullpath forKey: @"path"];
-        [dict setObject: @"GWFileCreatedInWatchedDirectory" forKey: @"event"];
-      
-        [self notifyGlobalWatchingClients: dict];
-      }      
-    }      
   }
+  else if ([event isEqual: @"GWFileCreatedInWatchedDirectory"])
+    {
+      NSArray *files = [info objectForKey: @"files"];
+      
+      for (i = 0; i < [files count]; i++)
+	{
+	  NSString *fname = [files objectAtIndex: i];
+	  NSString *fullpath = [path stringByAppendingPathComponent: fname];
+	  
+	  if ([self isGlobalValidPath: fullpath]) {
+	    NSMutableDictionary *dict = [NSMutableDictionary dictionary];
+	    
+	    [dict setObject: fullpath forKey: @"path"];
+	    [dict setObject: @"GWFileCreatedInWatchedDirectory" forKey: @"event"];
+	    
+	    [self notifyGlobalWatchingClients: dict];
+	  }      
+	}      
+    }
   
   RELEASE (pool);  
 }
 
 - (void)notifyGlobalWatchingClients:(NSDictionary *)info
 {
-  int i;
+  NSUInteger i;
 
-  for (i = 0; i < [clientsInfo count]; i++) {
-    FSWClientInfo *clinfo = [clientsInfo objectAtIndex: i];
-
-    if ([clinfo isGlobal]) {
-      [[clinfo client] globalWatchedPathDidChange: info];
+  for (i = 0; i < [clientsInfo count]; i++)
+    {
+      FSWClientInfo *clinfo = [clientsInfo objectAtIndex: i];
+      
+      if ([clinfo isGlobal])
+	[[clinfo client] globalWatchedPathDidChange: info];
     }
-  }
 }
 
 @end
@@ -671,9 +679,9 @@ static inline BOOL isDotFile(NSString *path)
 
 - (void)dealloc
 { 
-	if (timer && [timer isValid]) {
-		[timer invalidate];
-	}
+  if (timer && [timer isValid])
+    [timer invalidate];
+ 
   RELEASE (watchedPath);  
   RELEASE (pathContents);
   RELEASE (date);  
@@ -685,9 +693,10 @@ static inline BOOL isDotFile(NSString *path)
 {
   self = [super init];
   
-  if (self) { 
-		NSDictionary *attributes;
-		NSString *type;
+  if (self)
+    { 
+      NSDictionary *attributes;
+      NSString *type;
     		
     ASSIGN (watchedPath, path);    
 		fm = [NSFileManager defaultManager];	
@@ -723,12 +732,13 @@ static inline BOOL isDotFile(NSString *path)
   NSDate *moddate;
   NSMutableDictionary *notifdict;
 
-	if (isOld) {
-    RELEASE (pool);  
-		return;
-	}
+  if (isOld)
+    {
+      RELEASE (pool);  
+      return;
+    }
 	
-	attributes = [fm fileAttributesAtPath: watchedPath traverseLink: YES];
+  attributes = [fm fileAttributesAtPath: watchedPath traverseLink: YES];
 
   if (attributes == nil) {
     notifdict = [NSMutableDictionary dictionary];
@@ -833,7 +843,7 @@ static inline BOOL isDotFile(NSString *path)
   } 
 }
 
-- (BOOL)isWathcingPath:(NSString *)apath
+- (BOOL)isWatchingPath:(NSString *)apath
 {
   return ([apath isEqualToString: watchedPath]);
 }
@@ -861,7 +871,6 @@ int main(int argc, char** argv)
   CREATE_AUTORELEASE_POOL(pool);
   NSProcessInfo *info = [NSProcessInfo processInfo];
   NSMutableArray *args = AUTORELEASE ([[info arguments] mutableCopy]);
-  static BOOL	is_daemon = NO;
   BOOL subtask = YES;
 
   if ([[info arguments] containsObject: @"--auto"] == YES)
